BEGIN TRANSACTION;
CREATE TABLE IF NOT EXISTS "props" (
	"_id"	INTEGER,
	"key"	TEXT UNIQUE,
	"value"	TEXT,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "frequents" (
	"_id"	INTEGER,
	"jid"	TEXT NOT NULL,
	"type"	INTEGER NOT NULL,
	"message_count"	INTEGER NOT NULL,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "receipts" (
	"_id"	INTEGER,
	"key_remote_jid"	TEXT NOT NULL,
	"key_id"	TEXT NOT NULL,
	"remote_resource"	TEXT,
	"receipt_device_timestamp"	INTEGER,
	"read_device_timestamp"	INTEGER,
	"played_device_timestamp"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "group_participants" (
	"_id"	INTEGER,
	"gjid"	TEXT NOT NULL,
	"jid"	TEXT NOT NULL,
	"admin"	INTEGER,
	"pending"	INTEGER,
	"sent_sender_key"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "group_participants_history" (
	"_id"	INTEGER,
	"timestamp"	DATETIME NOT NULL,
	"gjid"	TEXT NOT NULL,
	"jid"	TEXT NOT NULL,
	"action"	INTEGER NOT NULL,
	"old_phash"	TEXT NOT NULL,
	"new_phash"	TEXT NOT NULL,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "media_refs" (
	"_id"	INTEGER,
	"path"	TEXT UNIQUE,
	"ref_count"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_thumbnails" (
	"thumbnail"	BLOB,
	"timestamp"	DATETIME,
	"key_remote_jid"	TEXT NOT NULL,
	"key_from_me"	INTEGER,
	"key_id"	TEXT NOT NULL
);
CREATE TABLE IF NOT EXISTS "status_list" (
	"_id"	INTEGER,
	"key_remote_jid"	TEXT UNIQUE,
	"message_table_id"	INTEGER,
	"last_read_message_table_id"	INTEGER,
	"last_read_receipt_sent_message_table_id"	INTEGER,
	"first_unread_message_table_id"	INTEGER,
	"autodownload_limit_message_table_id"	INTEGER,
	"timestamp"	INTEGER,
	"unseen_count"	INTEGER,
	"total_count"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "labels" (
	"_id"	INTEGER,
	"label_name"	TEXT,
	"predefined_id"	INTEGER,
	"color_id"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "labeled_messages" (
	"_id"	INTEGER,
	"label_id"	INTEGER NOT NULL,
	"message_row_id"	INTEGER NOT NULL,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "labeled_jids" (
	"_id"	INTEGER,
	"label_id"	INTEGER NOT NULL,
	"jid"	TEXT,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "missed_call_logs" (
	"_id"	INTEGER,
	"message_row_id"	INTEGER,
	"timestamp"	INTEGER,
	"video_call"	INTEGER,
	"group_jid_row_id"	INTEGER NOT NULL DEFAULT 0,
	"is_joinable_group_call"	INTEGER,
	"is_dnd_mode_on"	INTEGER,
	"offer_silence_reason"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "missed_call_log_participant" (
	"_id"	INTEGER,
	"call_logs_row_id"	INTEGER,
	"jid"	TEXT,
	"call_result"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "jid" (
	"_id"	INTEGER,
	"user"	TEXT NOT NULL,
	"server"	TEXT NOT NULL,
	"agent"	INTEGER,
	"type"	INTEGER,
	"raw_string"	TEXT,
	"device"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "chat" (
	"_id"	INTEGER,
	"jid_row_id"	INTEGER UNIQUE,
	"hidden"	INTEGER,
	"subject"	TEXT,
	"created_timestamp"	INTEGER,
	"display_message_row_id"	INTEGER,
	"last_message_row_id"	INTEGER,
	"last_read_message_row_id"	INTEGER,
	"last_read_receipt_sent_message_row_id"	INTEGER,
	"last_important_message_row_id"	INTEGER,
	"archived"	INTEGER,
	"sort_timestamp"	INTEGER,
	"mod_tag"	INTEGER,
	"gen"	REAL,
	"spam_detection"	INTEGER,
	"unseen_earliest_message_received_time"	INTEGER,
	"unseen_message_count"	INTEGER,
	"unseen_missed_calls_count"	INTEGER,
	"unseen_row_count"	INTEGER,
	"plaintext_disabled"	INTEGER,
	"vcard_ui_dismissed"	INTEGER,
	"change_number_notified_message_row_id"	INTEGER,
	"show_group_description"	INTEGER,
	"ephemeral_expiration"	INTEGER,
	"last_read_ephemeral_message_row_id"	INTEGER,
	"ephemeral_setting_timestamp"	INTEGER,
	"unseen_important_message_count"	INTEGER NOT NULL DEFAULT 0,
	"ephemeral_disappearing_messages_initiator"	INTEGER,
	"group_type"	INTEGER NOT NULL DEFAULT 0,
	"last_message_reaction_row_id"	INTEGER,
	"last_seen_message_reaction_row_id"	INTEGER,
	"unseen_message_reaction_count"	INTEGER,
	"growth_lock_level"	INTEGER,
	"growth_lock_expiration_ts"	INTEGER,
	"last_read_message_sort_id"	INTEGER,
	"display_message_sort_id"	INTEGER,
	"last_message_sort_id"	INTEGER,
	"last_read_receipt_sent_message_sort_id"	INTEGER,
	"has_new_community_admin_dialog_been_acknowledged"	INTEGER NOT NULL DEFAULT 0,
	"history_sync_progress"	INTEGER,
	"ephemeral_displayed_exemptions"	INTEGER,
	"chat_lock"	INTEGER,
	"chat_origin"	TEXT,
	"unseen_comment_message_count"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_product" (
	"message_row_id"	INTEGER,
	"business_owner_jid"	INTEGER,
	"product_id"	TEXT,
	"title"	TEXT,
	"description"	TEXT,
	"currency_code"	TEXT,
	"amount_1000"	INTEGER,
	"retailer_id"	TEXT,
	"url"	TEXT,
	"product_image_count"	INTEGER,
	"sale_amount_1000"	INTEGER,
	"body"	TEXT,
	"footer"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "call_log" (
	"_id"	INTEGER,
	"jid_row_id"	INTEGER,
	"from_me"	INTEGER,
	"call_id"	TEXT,
	"transaction_id"	INTEGER,
	"timestamp"	INTEGER,
	"video_call"	INTEGER,
	"duration"	INTEGER,
	"call_result"	INTEGER,
	"bytes_transferred"	INTEGER,
	"group_jid_row_id"	INTEGER NOT NULL DEFAULT 0,
	"is_joinable_group_call"	INTEGER,
	"call_creator_device_jid_row_id"	INTEGER NOT NULL DEFAULT 0,
	"call_random_id"	TEXT,
	"call_link_row_id"	INTEGER NOT NULL DEFAULT 0,
	"is_dnd_mode_on"	INTEGER,
	"call_type"	INTEGER,
	"offer_silence_reason"	INTEGER,
	"scheduled_id"	TEXT,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "call_log_participant_v2" (
	"_id"	INTEGER,
	"call_log_row_id"	INTEGER,
	"jid_row_id"	INTEGER,
	"call_result"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_group_invite" (
	"message_row_id"	INTEGER,
	"group_jid_row_id"	INTEGER NOT NULL,
	"admin_jid_row_id"	INTEGER NOT NULL,
	"group_name"	TEXT,
	"invite_code"	TEXT,
	"expiration"	INTEGER,
	"invite_time"	INTEGER,
	"expired"	INTEGER,
	"group_type"	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_quoted_group_invite_legacy" (
	"message_row_id"	INTEGER,
	"group_jid_row_id"	INTEGER NOT NULL,
	"admin_jid_row_id"	INTEGER NOT NULL,
	"group_name"	TEXT,
	"invite_code"	TEXT,
	"expiration"	INTEGER,
	"invite_time"	INTEGER,
	"expired"	INTEGER,
	"group_type"	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_forwarded" (
	"message_row_id"	INTEGER,
	"forward_score"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_template" (
	"message_row_id"	INTEGER,
	"content_text_data"	TEXT NOT NULL,
	"footer_text_data"	TEXT,
	"template_id"	TEXT,
	"csat_trigger_expiration_ts"	INTEGER,
	"category"	TEXT,
	"tag"	TEXT,
	"mask_linked_devices"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_template_button" (
	"_id"	INTEGER,
	"message_row_id"	INTEGER,
	"text_data"	TEXT NOT NULL,
	"extra_data"	TEXT,
	"button_type"	INTEGER,
	"used"	INTEGER,
	"selected_index"	INTEGER,
	"otp_button_type"	INTEGER,
	"extra_consent_data"	TEXT,
	"otp_matched_package_name"	TEXT,
	"webview_presentation"	INTEGER,
	"selected_carousel_card_index"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_template_quoted" (
	"message_row_id"	INTEGER,
	"content_text_data"	TEXT NOT NULL,
	"footer_text_data"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_location" (
	"message_row_id"	INTEGER,
	"chat_row_id"	INTEGER,
	"latitude"	REAL,
	"longitude"	REAL,
	"place_name"	TEXT,
	"place_address"	TEXT,
	"url"	TEXT,
	"live_location_share_duration"	INTEGER,
	"live_location_sequence_number"	INTEGER,
	"live_location_final_latitude"	REAL,
	"live_location_final_longitude"	REAL,
	"live_location_final_timestamp"	INTEGER,
	"map_download_status"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_quoted_location" (
	"message_row_id"	INTEGER,
	"latitude"	REAL,
	"longitude"	REAL,
	"place_name"	TEXT,
	"place_address"	TEXT,
	"url"	TEXT,
	"thumbnail"	BLOB,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_mentions" (
	"_id"	INTEGER,
	"message_row_id"	INTEGER,
	"jid_row_id"	INTEGER,
	"display_name"	STRING,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_orphaned_edit" (
	"_id"	INTEGER,
	"key_id"	TEXT NOT NULL,
	"from_me"	INTEGER NOT NULL,
	"chat_row_id"	INTEGER NOT NULL,
	"sender_jid_row_id"	INTEGER NOT NULL DEFAULT (0),
	"timestamp"	INTEGER,
	"message_type"	INTEGER NOT NULL,
	"revoked_key_id"	TEXT,
	"retry_count"	INTEGER,
	"admin_jid_row_id"	INTEGER,
	"orphan_message_data"	BLOB,
	PRIMARY KEY("_id")
);
CREATE TABLE IF NOT EXISTS "message_vcard" (
	"_id"	INTEGER,
	"message_row_id"	INTEGER,
	"vcard"	TEXT,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_vcard_jid" (
	"_id"	INTEGER,
	"vcard_jid_row_id"	INTEGER,
	"vcard_row_id"	INTEGER,
	"message_row_id"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_media" (
	"message_row_id"	INTEGER,
	"chat_row_id"	INTEGER,
	"autotransfer_retry_enabled"	INTEGER,
	"multicast_id"	TEXT,
	"media_job_uuid"	TEXT,
	"transferred"	INTEGER,
	"transcoded"	INTEGER,
	"file_path"	TEXT,
	"file_size"	INTEGER,
	"suspicious_content"	INTEGER,
	"trim_from"	INTEGER,
	"trim_to"	INTEGER,
	"face_x"	INTEGER,
	"face_y"	INTEGER,
	"media_key"	BLOB,
	"media_key_timestamp"	INTEGER,
	"width"	INTEGER,
	"height"	INTEGER,
	"has_streaming_sidecar"	INTEGER,
	"gif_attribution"	INTEGER,
	"thumbnail_height_width_ratio"	REAL,
	"direct_path"	TEXT,
	"first_scan_sidecar"	BLOB,
	"first_scan_length"	INTEGER,
	"message_url"	TEXT,
	"mime_type"	TEXT,
	"file_length"	INTEGER,
	"media_name"	TEXT,
	"file_hash"	TEXT,
	"media_duration"	INTEGER,
	"page_count"	INTEGER,
	"enc_file_hash"	TEXT,
	"partial_media_hash"	TEXT,
	"partial_media_enc_hash"	TEXT,
	"is_animated_sticker"	INTEGER,
	"original_file_hash"	TEXT,
	"mute_video"	INTEGER DEFAULT 0,
	"media_caption"	TEXT,
	"media_upload_handle"	TEXT,
	"sticker_flags"	INTEGER,
	"raw_transcription_text"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_media_interactive_annotation" (
	"_id"	INTEGER,
	"message_row_id"	INTEGER,
	"location_latitude"	REAL,
	"location_longitude"	REAL,
	"location_name"	TEXT,
	"sort_order"	INTEGER,
	"newsletter_jid_row_id"	INTEGER,
	"newsletter_server_message_id"	INTEGER,
	"newsletter_name"	TEXT,
	"skip_confirmation"	INTEGER NOT NULL DEFAULT 0,
	"newsletter_content_type"	INTEGER,
	"newsletter_accessibility_text"	TEXT,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_media_interactive_annotation_vertex" (
	"_id"	INTEGER,
	"message_media_interactive_annotation_row_id"	INTEGER,
	"x"	REAL,
	"y"	REAL,
	"sort_order"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_streaming_sidecar" (
	"message_row_id"	INTEGER,
	"sidecar"	BLOB,
	"chunk_lengths"	BLOB,
	"timestamp"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_quoted_media" (
	"message_row_id"	INTEGER,
	"media_job_uuid"	TEXT,
	"transferred"	INTEGER,
	"file_path"	TEXT,
	"file_size"	INTEGER,
	"media_key"	BLOB,
	"media_key_timestamp"	INTEGER,
	"width"	INTEGER,
	"height"	INTEGER,
	"direct_path"	TEXT,
	"message_url"	TEXT,
	"mime_type"	TEXT,
	"file_length"	INTEGER,
	"media_name"	TEXT,
	"file_hash"	TEXT,
	"media_duration"	INTEGER,
	"page_count"	INTEGER,
	"enc_file_hash"	TEXT,
	"thumbnail"	BLOB,
	"media_caption"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "user_device" (
	"_id"	INTEGER,
	"user_jid_row_id"	INTEGER,
	"device_jid_row_id"	INTEGER,
	"key_index"	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "deleted_chat_job" (
	"_id"	INTEGER,
	"chat_row_id"	INTEGER NOT NULL,
	"block_size"	INTEGER,
	"deleted_message_row_id"	INTEGER,
	"deleted_starred_message_row_id"	INTEGER,
	"deleted_messages_remove_files"	BOOLEAN,
	"deleted_categories_message_row_id"	INTEGER,
	"deleted_categories_starred_message_row_id"	INTEGER,
	"deleted_categories_remove_files"	BOOLEAN,
	"deleted_message_categories"	TEXT,
	"singular_message_delete_rows_id"	TEXT,
	"delete_files_singular_delete"	BOOLEAN,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_link" (
	"_id"	INTEGER,
	"chat_row_id"	INTEGER,
	"message_row_id"	INTEGER,
	"link_index"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_quoted" (
	"message_row_id"	INTEGER,
	"chat_row_id"	INTEGER NOT NULL,
	"parent_message_chat_row_id"	INTEGER NOT NULL,
	"from_me"	INTEGER NOT NULL,
	"sender_jid_row_id"	INTEGER,
	"key_id"	TEXT NOT NULL,
	"timestamp"	INTEGER,
	"message_type"	INTEGER,
	"text_data"	TEXT,
	"payment_transaction_id"	TEXT,
	"lookup_tables"	INTEGER,
	"origin"	INTEGER,
	PRIMARY KEY("message_row_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_quoted_mentions" (
	"_id"	INTEGER,
	"message_row_id"	INTEGER,
	"jid_row_id"	INTEGER,
	"display_name"	STRING,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_thumbnail" (
	"message_row_id"	INTEGER,
	"thumbnail"	BLOB,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_quoted_vcard" (
	"_id"	INTEGER,
	"message_row_id"	INTEGER,
	"vcard"	TEXT,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_text" (
	"message_row_id"	INTEGER,
	"description"	TEXT,
	"page_title"	TEXT,
	"url"	TEXT,
	"font_style"	INTEGER,
	"text_color"	INTEGER,
	"background_color"	INTEGER,
	"preview_type"	INTEGER,
	"invite_link_group_type"	INTEGER NOT NULL DEFAULT 0,
	"counter_abuse_token"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_quoted_text" (
	"message_row_id"	INTEGER,
	"thumbnail"	BLOB,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_quoted_product" (
	"message_row_id"	INTEGER,
	"business_owner_jid"	INTEGER,
	"product_id"	TEXT,
	"title"	TEXT,
	"description"	TEXT,
	"currency_code"	TEXT,
	"amount_1000"	INTEGER,
	"retailer_id"	TEXT,
	"url"	TEXT,
	"product_image_count"	INTEGER,
	"sale_amount_1000"	INTEGER,
	"body"	TEXT,
	"footer"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_quoted_group_invite" (
	"message_row_id"	INTEGER,
	"group_jid_row_id"	INTEGER NOT NULL,
	"admin_jid_row_id"	INTEGER NOT NULL,
	"group_name"	TEXT,
	"invite_code"	TEXT,
	"expiration"	INTEGER,
	"invite_time"	INTEGER,
	"expired"	INTEGER,
	"group_type"	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_future" (
	"message_row_id"	INTEGER,
	"version"	INTEGER,
	"data"	BLOB,
	"future_message_type"	INTEGER,
	"future_proof_stanza"	BLOB,
	"edit_version"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_send_count" (
	"message_row_id"	INTEGER,
	"send_count"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "receipt_device" (
	"_id"	INTEGER,
	"message_row_id"	INTEGER NOT NULL,
	"receipt_device_jid_row_id"	INTEGER NOT NULL,
	"receipt_device_timestamp"	INTEGER,
	"primary_device_version"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message" (
	"_id"	INTEGER,
	"chat_row_id"	INTEGER NOT NULL,
	"from_me"	INTEGER NOT NULL,
	"key_id"	TEXT NOT NULL,
	"sender_jid_row_id"	INTEGER,
	"status"	INTEGER,
	"broadcast"	INTEGER,
	"recipient_count"	INTEGER,
	"participant_hash"	TEXT,
	"origination_flags"	INTEGER,
	"origin"	INTEGER,
	"timestamp"	INTEGER,
	"received_timestamp"	INTEGER,
	"receipt_server_timestamp"	INTEGER,
	"message_type"	INTEGER,
	"text_data"	TEXT,
	"starred"	INTEGER,
	"lookup_tables"	INTEGER,
	"sort_id"	INTEGER NOT NULL DEFAULT 0,
	"message_add_on_flags"	INTEGER,
	"view_mode"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_system" (
	"message_row_id"	INTEGER,
	"action_type"	INTEGER NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_group" (
	"message_row_id"	INTEGER,
	"is_me_joined"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_value_change" (
	"message_row_id"	INTEGER,
	"old_data"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_number_change" (
	"message_row_id"	INTEGER,
	"old_jid_row_id"	INTEGER,
	"new_jid_row_id"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_photo_change" (
	"message_row_id"	INTEGER,
	"new_photo_id"	TEXT,
	"old_photo"	BLOB,
	"new_photo"	BLOB,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_chat_participant" (
	"message_row_id"	INTEGER,
	"user_jid_row_id"	INTEGER
);
CREATE TABLE IF NOT EXISTS "message_payment" (
	"message_row_id"	INTEGER,
	"sender_jid_row_id"	INTEGER,
	"receiver_jid_row_id"	INTEGER,
	"amount_with_symbol"	TEXT,
	"remote_resource"	TEXT,
	"remote_message_sender_jid_row_id"	INTEGER,
	"remote_message_from_me"	INTEGER,
	"remote_message_key"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_payment_transaction_reminder" (
	"message_row_id"	INTEGER,
	"web_stub"	TEXT,
	"amount"	TEXT,
	"transfer_date"	TEXT,
	"payment_sender_name"	INTEGER,
	"expiration"	INTEGER,
	"remote_message_key"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_payment_status_update" (
	"message_row_id"	INTEGER,
	"transaction_info"	TEXT,
	"transaction_data"	TEXT,
	"init_timestamp"	TEXT,
	"update_timestamp"	TEXT,
	"amount_data"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "labeled_jid" (
	"_id"	INTEGER,
	"label_id"	INTEGER NOT NULL,
	"jid_row_id"	INTEGER NOT NULL,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "frequent" (
	"_id"	INTEGER,
	"jid_row_id"	INTEGER NOT NULL,
	"type"	INTEGER NOT NULL,
	"message_count"	INTEGER NOT NULL,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "receipt_user" (
	"_id"	INTEGER,
	"message_row_id"	INTEGER NOT NULL,
	"receipt_user_jid_row_id"	INTEGER NOT NULL,
	"receipt_timestamp"	INTEGER,
	"read_timestamp"	INTEGER,
	"played_timestamp"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "status" (
	"_id"	INTEGER,
	"jid_row_id"	INTEGER UNIQUE,
	"message_table_id"	INTEGER,
	"last_read_message_table_id"	INTEGER,
	"last_read_receipt_sent_message_table_id"	INTEGER,
	"first_unread_message_table_id"	INTEGER,
	"autodownload_limit_message_table_id"	INTEGER,
	"timestamp"	INTEGER,
	"unseen_count"	INTEGER,
	"total_count"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "group_participant_device" (
	"_id"	INTEGER,
	"group_participant_row_id"	INTEGER NOT NULL,
	"device_jid_row_id"	INTEGER NOT NULL,
	"sent_sender_key"	INTEGER,
	"sent_add_on_sender_key"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_revoked" (
	"message_row_id"	INTEGER,
	"revoked_key_id"	TEXT NOT NULL,
	"admin_jid_row_id"	INTEGER,
	"revoke_timestamp"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "messages_hydrated_four_row_template" (
	"message_row_id"	INTEGER,
	"message_template_id"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "pay_transaction" (
	"_id"	INTEGER,
	"message_row_id"	INTEGER,
	"remote_jid_row_id"	INTEGER,
	"key_id"	TEXT,
	"interop_id"	TEXT,
	"id"	TEXT,
	"timestamp"	INTEGER,
	"status"	INTEGER,
	"error_code"	TEXT,
	"sender_jid_row_id"	INTEGER,
	"receiver_jid_row_id"	INTEGER,
	"type"	INTEGER,
	"currency_code"	TEXT,
	"amount_1000"	,
	"credential_id"	TEXT,
	"methods"	TEXT,
	"bank_transaction_id"	TEXT,
	"metadata"	TEXT,
	"init_timestamp"	INTEGER,
	"request_key_id"	TEXT,
	"country"	TEXT,
	"version"	INTEGER,
	"future_data"	BLOB,
	"service_id"	INTEGER,
	"background_id"	TEXT,
	"purchase_initiator"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "group_participant_user" (
	"_id"	INTEGER,
	"group_jid_row_id"	INTEGER NOT NULL,
	"user_jid_row_id"	INTEGER NOT NULL,
	"rank"	INTEGER,
	"pending"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_system_device_change" (
	"message_row_id"	INTEGER,
	"device_added_count"	INTEGER,
	"device_removed_count"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_block_contact" (
	"message_row_id"	INTEGER,
	"is_blocked"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "conversion_tuples" (
	"jid_row_id"	INTEGER,
	"data"	TEXT,
	"source"	TEXT,
	"biz_count"	INTEGER,
	"has_user_sent_last_message"	BOOLEAN,
	"last_interaction"	INTEGER,
	PRIMARY KEY("jid_row_id")
);
CREATE TABLE IF NOT EXISTS "labeled_messages_fts_content" (
	"docid"	INTEGER,
	"c0content"	,
	PRIMARY KEY("docid")
);
CREATE TABLE IF NOT EXISTS "labeled_messages_fts_segments" (
	"blockid"	INTEGER,
	"block"	BLOB,
	PRIMARY KEY("blockid")
);
CREATE TABLE IF NOT EXISTS "labeled_messages_fts_segdir" (
	"level"	INTEGER,
	"idx"	INTEGER,
	"start_block"	INTEGER,
	"leaves_end_block"	INTEGER,
	"end_block"	INTEGER,
	"root"	BLOB,
	PRIMARY KEY("level","idx")
);
CREATE TABLE IF NOT EXISTS "away_messages" (
	"_id"	INTEGER,
	"jid"	TEXT NOT NULL UNIQUE,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "away_messages_exemptions" (
	"_id"	INTEGER,
	"jid"	TEXT NOT NULL UNIQUE,
	"exempt"	BOOLEAN,
	"exempt_until"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "quick_replies" (
	"_id"	INTEGER,
	"title"	TEXT NOT NULL UNIQUE,
	"content"	TEXT NOT NULL,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "quick_reply_usage" (
	"_id"	INTEGER,
	"quick_reply_id"	TEXT NOT NULL,
	"usage_date"	DATE,
	"usage_count"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "quick_reply_keywords" (
	"_id"	INTEGER,
	"quick_reply_id"	TEXT NOT NULL,
	"keyword_id"	TEXT NOT NULL,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "keywords" (
	"_id"	INTEGER,
	"keyword"	TEXT NOT NULL UNIQUE,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "quick_reply_attachments" (
	"_id"	INTEGER,
	"quick_reply_id"	TEXT NOT NULL,
	"uri"	TEXT NOT NULL,
	"caption"	TEXT,
	"media_type"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "media_hash_thumbnail" (
	"media_hash"	TEXT,
	"thumbnail"	BLOB,
	PRIMARY KEY("media_hash")
);
CREATE TABLE IF NOT EXISTS "receipt_orphaned" (
	"_id"	INTEGER,
	"chat_row_id"	INTEGER NOT NULL,
	"from_me"	INTEGER NOT NULL,
	"key_id"	TEXT NOT NULL,
	"receipt_device_jid_row_id"	INTEGER NOT NULL,
	"receipt_recipient_jid_row_id"	INTEGER,
	"status"	INTEGER,
	"timestamp"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_media_vcard_count" (
	"_id"	INTEGER,
	"message_row_id"	INTEGER,
	"count"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "group_notification_version" (
	"group_jid_row_id"	INTEGER,
	"subject_timestamp"	INTEGER NOT NULL,
	"announcement_version"	INTEGER NOT NULL,
	"participant_version"	INTEGER NOT NULL,
	PRIMARY KEY("group_jid_row_id")
);
CREATE TABLE IF NOT EXISTS "user_device_info" (
	"user_jid_row_id"	INTEGER,
	"raw_id"	INTEGER NOT NULL,
	"timestamp"	INTEGER NOT NULL,
	"expected_timestamp"	INTEGER,
	"expected_ts_last_device_job_ts"	INTEGER,
	"expected_timestamp_update_ts"	INTEGER,
	"account_encryption_type"	INTEGER,
	PRIMARY KEY("user_jid_row_id")
);
CREATE TABLE IF NOT EXISTS "message_ephemeral_setting" (
	"message_row_id"	INTEGER,
	"setting_duration"	INTEGER,
	"setting_reason"	INTEGER,
	"user_jid_row_id_csv"	TEXT,
	"ephemeral_trigger"	INTEGER,
	"ephemeral_initiated_by_me"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_external_ad_content" (
	"message_row_id"	INTEGER,
	"title"	TEXT,
	"body"	TEXT,
	"media_type"	INTEGER,
	"thumbnail_url"	TEXT,
	"full_thumbnail"	BLOB,
	"micro_thumbnail"	BLOB,
	"media_url"	TEXT,
	"source_type"	TEXT,
	"source_id"	TEXT,
	"source_url"	TEXT,
	"render_larger_thumbnail"	BOOLEAN,
	"show_ad_attribution"	BOOLEAN,
	"has_icebreaker_auto_response"	BOOLEAN,
	"has_click_to_call_auto_response"	BOOLEAN,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_ephemeral_setting_not_applied" (
	"message_row_id"	INTEGER,
	"setting_duration"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_ui_elements" (
	"_id"	INTEGER NOT NULL,
	"message_row_id"	INTEGER NOT NULL,
	"element_type"	INTEGER,
	"element_content"	TEXT,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_order" (
	"message_row_id"	INTEGER,
	"order_id"	TEXT,
	"thumbnail"	BLOB,
	"order_title"	TEXT,
	"item_count"	INTEGER,
	"status"	INTEGER,
	"surface"	INTEGER,
	"message"	TEXT,
	"seller_jid"	INTEGER,
	"token"	TEXT,
	"currency_code"	TEXT,
	"total_amount_1000"	INTEGER,
	"message_version"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_quoted_order" (
	"message_row_id"	INTEGER,
	"order_id"	TEXT,
	"thumbnail"	BLOB,
	"order_title"	TEXT,
	"item_count"	INTEGER,
	"status"	INTEGER,
	"surface"	INTEGER,
	"message"	TEXT,
	"seller_jid"	INTEGER,
	"token"	TEXT,
	"currency_code"	TEXT,
	"total_amount_1000"	INTEGER,
	"message_version"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_view_once_media" (
	"message_row_id"	INTEGER,
	"state"	INTEGER NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "mms_thumbnail_metadata" (
	"message_row_id"	INTEGER,
	"direct_path"	TEXT,
	"media_key"	BLOB,
	"media_key_timestamp"	INTEGER,
	"enc_thumb_hash"	TEXT,
	"thumb_hash"	TEXT,
	"thumb_width"	INTEGER,
	"thumb_height"	INTEGER,
	"transferred"	INTEGER,
	"micro_thumbnail"	BLOB,
	"insert_timestamp"	INTEGER,
	"handle"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_quoted_ui_elements" (
	"message_row_id"	INTEGER NOT NULL,
	"element_type"	INTEGER,
	"element_content"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_ui_elements_reply" (
	"message_row_id"	INTEGER,
	"element_type"	INTEGER,
	"reply_values"	TEXT,
	"reply_description"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_quoted_ui_elements_reply" (
	"message_row_id"	INTEGER,
	"element_type"	INTEGER,
	"reply_values"	TEXT,
	"reply_description"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_initial_privacy_provider" (
	"message_row_id"	INTEGER,
	"privacy_provider"	INTEGER NOT NULL DEFAULT 0,
	"verified_biz_name"	TEXT,
	"biz_state_id"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_privacy_state" (
	"message_row_id"	INTEGER NOT NULL,
	"host_storage"	INTEGER,
	"actual_actors"	INTEGER,
	"privacy_mode_ts"	INTEGER NOT NULL,
	"business_name"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_business_state" (
	"message_row_id"	INTEGER,
	"privacy_message_type"	INTEGER NOT NULL,
	"business_name"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_invoice" (
	"message_row_id"	INTEGER,
	"wa_invoice_id"	TEXT NOT NULL,
	"amount"	TEXT NOT NULL,
	"note"	TEXT NOT NULL,
	"token"	TEXT,
	"sender_jid_row_id"	INTEGER,
	"receiver_jid_row_id"	INTEGER,
	"status"	INTEGER,
	"status_ts"	INTEGER,
	"creation_ts"	INTEGER,
	"attachment_type"	INTEGER,
	"attachment_mimetype"	TEXT,
	"attachment_media_key"	BLOB,
	"attachment_media_key_ts"	INTEGER,
	"attachment_file_sha256"	BLOB,
	"attachment_file_enc_sha256"	BLOB,
	"attachment_direct_path"	TEXT,
	"attachment_jpeg_thumbnail"	BLOB,
	"metadata"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_quote_invoice" (
	"message_row_id"	INTEGER,
	"amount"	TEXT NOT NULL,
	"note"	TEXT NOT NULL,
	"status"	INTEGER,
	"attachment_jpeg_thumbnail"	BLOB,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "invoice_transactions" (
	"message_row_id"	INTEGER,
	"pay_transaction_id"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_ephemeral" (
	"message_row_id"	INTEGER,
	"duration"	INTEGER NOT NULL,
	"expire_timestamp"	INTEGER NOT NULL,
	"keep_in_chat"	INTEGER NOT NULL DEFAULT 0,
	"ephemeral_trigger"	INTEGER,
	"ephemeral_initiated_by_me"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "played_self_receipt" (
	"message_row_id"	INTEGER,
	"to_jid_row_id"	INTEGER NOT NULL,
	"participant_jid_row_id"	INTEGER,
	"message_id"	TEXT NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_broadcast_ephemeral" (
	"message_row_id"	INTEGER,
	"shared_secret"	BLOB NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_quoted_ui_elements_reply_legacy" (
	"message_row_id"	INTEGER,
	"element_type"	INTEGER,
	"reply_values"	TEXT,
	"reply_description"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_payment_invite" (
	"message_row_id"	INTEGER,
	"service"	INTEGER,
	"expiration_timestamp"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_quoted_payment_invite" (
	"message_row_id"	INTEGER,
	"service"	INTEGER,
	"expiration_timestamp"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_payment_invite_setup" (
	"message_row_id"	INTEGER,
	"service"	INTEGER,
	"invite_used"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "payment_background" (
	"background_id"	TEXT,
	"file_size"	INTEGER,
	"width"	INTEGER,
	"height"	INTEGER,
	"mime_type"	TEXT,
	"placeholder_color"	INTEGER,
	"text_color"	INTEGER,
	"subtext_color"	INTEGER,
	"fullsize_url"	TEXT,
	"description"	TEXT,
	"lg"	TEXT,
	"media_key"	BLOB,
	"media_key_timestamp"	INTEGER,
	"file_sha256"	TEXT,
	"file_enc_sha256"	TEXT,
	"direct_path"	TEXT,
	PRIMARY KEY("background_id")
);
CREATE TABLE IF NOT EXISTS "payment_background_order" (
	"background_id"	TEXT,
	"background_order"	INTEGER,
	PRIMARY KEY("background_id")
);
CREATE TABLE IF NOT EXISTS "joinable_call_log" (
	"call_log_row_id"	INTEGER,
	"call_id"	TEXT NOT NULL,
	"group_jid_row_id"	INTEGER NOT NULL DEFAULT 0,
	"joinable_video_call"	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY("call_log_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_linked_group_call" (
	"message_row_id"	INTEGER,
	"call_id"	TEXT,
	"is_video_call"	INTEGER,
	"call_type"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "audio_data" (
	"message_row_id"	INTEGER,
	"waveform"	BLOB,
	"background_color"	INTEGER NOT NULL DEFAULT 0,
	"transcription_status"	INTEGER,
	"transcription_locale"	INTEGER,
	"transcription_confidence_threshold"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_rating" (
	"message_row_id"	INTEGER,
	"rating"	INTEGER NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_status_psa_campaign" (
	"message_row_id"	INTEGER,
	"campaign_id"	TEXT,
	"duration"	INTEGER,
	"first_seen_timestamp"	INTEGER,
	"action_link_url"	TEXT,
	"action_link_button_title"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "primary_device_version" (
	"user_jid_row_id"	INTEGER,
	"version"	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY("user_jid_row_id")
);
CREATE TABLE IF NOT EXISTS "message_add_on" (
	"_id"	INTEGER,
	"chat_row_id"	INTEGER,
	"from_me"	INTEGER,
	"key_id"	TEXT NOT NULL,
	"sender_jid_row_id"	INTEGER,
	"parent_message_row_id"	INTEGER,
	"timestamp"	INTEGER,
	"status"	INTEGER,
	"message_add_on_type"	INTEGER,
	"received_timestamp"	INTEGER,
	"expiry_duration_in_secs"	INTEGER,
	"server_timestamp"	INTEGER,
	"expiry_timestamp"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_add_on_orphan" (
	"_id"	INTEGER,
	"chat_row_id"	INTEGER,
	"from_me"	INTEGER,
	"key_id"	TEXT NOT NULL,
	"sender_jid_row_id"	INTEGER,
	"parent_chat_row_id"	INTEGER,
	"parent_from_me"	INTEGER,
	"parent_key_id"	TEXT NOT NULL,
	"parent_sender_jid_row_id"	INTEGER,
	"timestamp"	INTEGER,
	"orphan_message_data"	BLOB,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_add_on_reaction" (
	"message_add_on_row_id"	INTEGER,
	"reaction"	TEXT,
	"sender_timestamp"	INTEGER,
	PRIMARY KEY("message_add_on_row_id")
);
CREATE TABLE IF NOT EXISTS "message_add_on_receipt_device" (
	"receipt_device_id"	INTEGER,
	"message_add_on_row_id"	INTEGER,
	"receipt_device_jid_row_id"	INTEGER,
	"receipt_device_timestamp"	INTEGER,
	"primary_device_version"	INTEGER,
	PRIMARY KEY("receipt_device_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_quoted_blank_reply" (
	"message_row_id"	INTEGER,
	"parent_group_jid"	TEXT,
	"group_subject"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_community_link_changed" (
	"message_row_id"	INTEGER,
	"old_group_type"	INTEGER,
	"new_group_type"	INTEGER NOT NULL,
	"linked_parent_group_jid_row_id"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_sibling_group_link_change" (
	"message_row_id"	INTEGER NOT NULL,
	"subgroup_raw_jid"	TEXT NOT NULL,
	"subgroup_subject"	TEXT NOT NULL,
	"parent_group_jid_row_id"	INTEGER,
	PRIMARY KEY("message_row_id","subgroup_raw_jid")
);
CREATE TABLE IF NOT EXISTS "jid_map" (
	"lid_row_id"	INTEGER NOT NULL,
	"jid_row_id"	INTEGER NOT NULL,
	PRIMARY KEY("lid_row_id")
);
CREATE TABLE IF NOT EXISTS "agent_devices" (
	"agent_id"	TEXT NOT NULL,
	"agent_name"	TEXT NOT NULL UNIQUE,
	"device"	INTEGER,
	"last_modified_time"	INTEGER,
	"is_deleted"	BOOLEAN,
	PRIMARY KEY("agent_id")
);
CREATE TABLE IF NOT EXISTS "group_past_participant_user" (
	"_id"	INTEGER,
	"group_jid_row_id"	INTEGER NOT NULL,
	"user_jid_row_id"	INTEGER NOT NULL,
	"is_leave"	INTEGER NOT NULL,
	"timestamp"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "agent_message_attribution" (
	"message_row_id"	INTEGER,
	"agent_id"	TEXT NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_poll" (
	"message_row_id"	INTEGER,
	"enc_key"	BLOB,
	"selectable_options_count"	INTEGER,
	"invalid_state"	INTEGER NOT NULL DEFAULT 0,
	"poll_logging_id"	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_poll_option" (
	"_id"	INTEGER,
	"message_row_id"	INTEGER,
	"option_sha256"	TEXT,
	"option_name"	TEXT,
	"vote_total"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_add_on_poll_vote" (
	"message_add_on_row_id"	INTEGER,
	"sender_timestamp"	INTEGER,
	PRIMARY KEY("message_add_on_row_id")
);
CREATE TABLE IF NOT EXISTS "message_add_on_poll_vote_selected_option" (
	"_id"	INTEGER,
	"message_add_on_row_id"	INTEGER,
	"message_poll_option_id"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_add_on_keep_in_chat" (
	"message_add_on_row_id"	INTEGER,
	"keep_in_chat_state"	INTEGER NOT NULL DEFAULT 0,
	"sender_timestamp"	INTEGER,
	"keep_count"	INTEGER NOT NULL DEFAULT 0,
	"actor_device_jid_row_id"	INTEGER,
	PRIMARY KEY("message_add_on_row_id")
);
CREATE TABLE IF NOT EXISTS "message_secret" (
	"message_row_id"	INTEGER,
	"message_secret"	BLOB,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "lid_display_name" (
	"lid_row_id"	INTEGER NOT NULL,
	"display_name"	TEXT NOT NULL,
	"username"	TEXT,
	PRIMARY KEY("lid_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_group_with_parent" (
	"message_row_id"	INTEGER,
	"linked_parent_group_name"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "community_chat" (
	"chat_row_id"	INTEGER,
	"last_activity_ts"	INTEGER,
	"last_activity_seen_ts"	INTEGER,
	"join_ts"	INTEGER,
	"closed"	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY("chat_row_id")
);
CREATE TABLE IF NOT EXISTS "agent_chat_assignment" (
	"jid_row_id"	INTEGER,
	"agent_id"	TEXT NOT NULL,
	"is_opened"	BOOLEAN,
	PRIMARY KEY("jid_row_id")
);
CREATE TABLE IF NOT EXISTS "call_link" (
	"_id"	INTEGER,
	"token"	TEXT NOT NULL,
	"creator_jid_row_id"	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "lid_chat_state" (
	"jid_row_id"	INTEGER NOT NULL,
	"is_pn_shared"	INTEGER NOT NULL DEFAULT 0,
	"pn_requested_ts"	INTEGER NOT NULL DEFAULT 0,
	"pnh_duplicate_lid_thread"	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY("jid_row_id")
);
CREATE TABLE IF NOT EXISTS "message_details" (
	"message_row_id"	INTEGER,
	"author_device_jid"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_chat_assignment" (
	"message_row_id"	INTEGER,
	"agent_name"	TEXT,
	"is_unassigned_chat"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "parent_group_participants" (
	"parent_group_jid_row_id"	INTEGER NOT NULL,
	"user_jid_row_id"	INTEGER NOT NULL
);
CREATE TABLE IF NOT EXISTS "android_metadata" (
	"locale"	TEXT
);
CREATE TABLE IF NOT EXISTS "message_edit_info" (
	"message_row_id"	INTEGER,
	"original_key_id"	TEXT NOT NULL,
	"edited_timestamp"	INTEGER NOT NULL,
	"sender_timestamp"	INTEGER NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_with_group_nodes" (
	"message_row_id"	INTEGER NOT NULL,
	"group_jid_row_id"	INTEGER NOT NULL,
	"group_node_type"	INTEGER NOT NULL,
	"group_subject"	TEXT,
	"version"	INTEGER,
	PRIMARY KEY("message_row_id","group_jid_row_id","group_node_type")
);
CREATE TABLE IF NOT EXISTS "message_ephemeral_sync_response" (
	"chat_jid"	TEXT NOT NULL,
	"last_sync_response_sent_timestamp"	INTEGER NOT NULL,
	"no_of_retries_sent_already"	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY("chat_jid")
);
CREATE TABLE IF NOT EXISTS "backup_changes" (
	"_id"	INTEGER,
	"operation"	TEXT NOT NULL,
	"table_name"	TEXT NOT NULL,
	"table_row_id"	INTEGER NOT NULL,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "smb_order" (
	"_id"	INTEGER,
	"status"	TEXT,
	"jid_row_id"	INTEGER NOT NULL,
	"reference_id"	TEXT NOT NULL,
	"transaction_id"	TEXT,
	"payment_type"	TEXT,
	"content"	TEXT,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_add_on_pin_in_chat" (
	"message_add_on_row_id"	INTEGER,
	"pin_in_chat_state"	INTEGER NOT NULL DEFAULT 0,
	"sender_timestamp"	INTEGER,
	PRIMARY KEY("message_add_on_row_id")
);
CREATE TABLE IF NOT EXISTS "priority_inbox" (
	"_id"	INTEGER,
	"priority_score"	DOUBLE NOT NULL,
	"version"	INTEGER NOT NULL,
	"chat_row_id"	INTEGER NOT NULL,
	"is_priority"	BOOLEAN,
	"label_removed"	BOOLEAN,
	"time_created"	INTEGER,
	"deep_conversion_rate"	BOOLEAN,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "suggested_replies" (
	"message_row_id"	INTEGER,
	"customer_message_row_id"	INTEGER NOT NULL,
	"tokenized_customer_message"	STRING,
	"customer_message_embedding"	BLOB,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_scheduled_call" (
	"message_row_id"	INTEGER,
	"scheduled_timestamp_ms"	INTEGER,
	"call_type"	INTEGER,
	"title"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_scheduled_call_start" (
	"message_row_id"	INTEGER,
	"creation_message_row_id"	INTEGER NOT NULL UNIQUE,
	"call_title"	TEXT NOT NULL,
	"call_timestamp_ms"	INTEGER NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "scheduled_calls" (
	"creation_message_row_id"	INTEGER,
	"key_id"	TEXT NOT NULL,
	"key_from_me"	INTEGER NOT NULL,
	"key_chat_row_id"	INTEGER NOT NULL,
	"call_type"	INTEGER NOT NULL,
	"scheduled_timestamp"	INTEGER NOT NULL,
	"call_title"	TEXT NOT NULL,
	"creator_jid_row_id"	INTEGER NOT NULL,
	"is_upcoming"	BOOLEAN NOT NULL,
	"call_log_row_id"	INTEGER,
	PRIMARY KEY("creation_message_row_id")
);
CREATE TABLE IF NOT EXISTS "newsletter" (
	"chat_row_id"	INTEGER,
	"name"	TEXT NOT NULL,
	"name_id"	INTEGER NOT NULL,
	"description"	TEXT NOT NULL,
	"description_id"	INTEGER NOT NULL,
	"picture_url"	TEXT,
	"picture_id"	INTEGER NOT NULL,
	"preview_url"	TEXT,
	"preview_id"	INTEGER NOT NULL,
	"invite_code"	TEXT,
	"handle"	TEXT,
	"subscribers_count"	INTEGER NOT NULL,
	"membership"	INTEGER NOT NULL,
	"privacy"	INTEGER NOT NULL,
	"verified"	INTEGER NOT NULL,
	"muted"	INTEGER NOT NULL,
	"oldest_message_retrieved"	INTEGER NOT NULL,
	"suspended"	INTEGER NOT NULL DEFAULT 0,
	"deleted"	INTEGER NOT NULL DEFAULT 0,
	"show_enforced_update_banner"	INTEGER,
	"reaction_setting"	INTEGER,
	"reaction_setting_blocklist"	STRING,
	"reaction_setting_update_ts"	INTEGER,
	"verification_source"	INTEGER,
	"admin_count"	INTEGER,
	PRIMARY KEY("chat_row_id")
);
CREATE TABLE IF NOT EXISTS "newsletter_linked_account" (
	"_id"	INTEGER,
	"chat_row_id"	INTEGER NOT NULL,
	"name"	TEXT NOT NULL,
	"link"	TEXT NOT NULL,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "newsletter_message" (
	"message_row_id"	INTEGER,
	"chat_row_id"	INTEGER NOT NULL,
	"server_message_id"	INTEGER NOT NULL,
	"comments_count"	INTEGER NOT NULL,
	"reaction_from_me"	TEXT,
	"extra_newsletter_tables"	INTEGER NOT NULL DEFAULT 0,
	"extra_table_last_update_ts"	INTEGER,
	"reactions_from_me_ts"	INTEGER,
	"view_count"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "integrator_display_name" (
	"integrator_id"	INTEGER NOT NULL,
	"display_name"	TEXT NOT NULL,
	"status"	INTEGER NOT NULL,
	"icon_path"	TEXT NOT NULL DEFAULT '',
	"opt_in_status"	INTEGER NOT NULL DEFAULT 0,
	"identifier_type"	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY("integrator_id")
);
CREATE TABLE IF NOT EXISTS "messages_quotes" (
	"_id"	INTEGER,
	"key_remote_jid"	TEXT NOT NULL,
	"key_from_me"	INTEGER,
	"key_id"	TEXT NOT NULL,
	"status"	INTEGER,
	"needs_push"	INTEGER,
	"data"	TEXT,
	"timestamp"	INTEGER,
	"media_url"	TEXT,
	"media_mime_type"	TEXT,
	"media_wa_type"	TEXT,
	"media_size"	INTEGER,
	"media_name"	TEXT,
	"media_caption"	TEXT,
	"media_hash"	TEXT,
	"media_duration"	INTEGER,
	"origin"	INTEGER,
	"latitude"	REAL,
	"longitude"	REAL,
	"thumb_image"	TEXT,
	"remote_resource"	TEXT,
	"received_timestamp"	INTEGER,
	"send_timestamp"	INTEGER,
	"receipt_server_timestamp"	INTEGER,
	"receipt_device_timestamp"	INTEGER,
	"read_device_timestamp"	INTEGER,
	"played_device_timestamp"	INTEGER,
	"raw_data"	BLOB,
	"recipient_count"	INTEGER,
	"participant_hash"	TEXT,
	"starred"	INTEGER,
	"quoted_row_id"	INTEGER,
	"mentioned_jids"	TEXT,
	"multicast_id"	TEXT,
	"edit_version"	INTEGER,
	"media_enc_hash"	TEXT,
	"payment_transaction_id"	TEXT,
	"forwarded"	INTEGER,
	"preview_type"	INTEGER,
	"send_count"	INTEGER,
	"lookup_tables"	INTEGER,
	"future_message_type"	INTEGER,
	"message_add_on_flags"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "suggest_as_you_type" (
	"message_row_id"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "status_crossposting" (
	"status_message_row_id"	INTEGER,
	"crossposting_session_id"	TEXT,
	"crossposting_status_unique_id"	TEXT,
	"state"	INTEGER,
	"media_path"	TEXT,
	PRIMARY KEY("status_message_row_id")
);
CREATE TABLE IF NOT EXISTS "smart_suggestions_key_value" (
	"_id"	INTEGER,
	"key"	TEXT UNIQUE,
	"value"	BLOB,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "template_messages_metadata" (
	"message_row_id"	INTEGER,
	"message_template_id"	TEXT,
	"message_hsm_tag"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_add_on_scheduled_call_edit" (
	"message_add_on_row_id"	INTEGER,
	"edit_type"	INTEGER NOT NULL DEFAULT 0,
	"message_edit_version"	INTEGER,
	PRIMARY KEY("message_add_on_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_group_auto_restrict" (
	"message_row_id"	INTEGER,
	"threshold"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "newsletter_message_reaction" (
	"_id"	INTEGER,
	"message_row_id"	INTEGER NOT NULL,
	"reaction"	TEXT NOT NULL,
	"reaction_count"	INTEGER NOT NULL,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_bot_feedback" (
	"message_row_id"	INTEGER,
	"bot_feedback_kind"	INTEGER NOT NULL,
	"bot_feedback_text"	TEXT NOT NULL,
	"bot_feedback_key_remote_jid"	TEXT NOT NULL,
	"bot_feedback_key_from_me"	INTEGER NOT NULL,
	"bot_feedback_key_id"	TEXT NOT NULL,
	"bot_feedback_kind_positive"	INTEGER NOT NULL DEFAULT 0,
	"bot_feedback_kind_negative"	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "forwarded_newsletter_message_info" (
	"message_row_id"	INTEGER,
	"newsletter_jid_row_id"	INTEGER NOT NULL,
	"newsletter_server_message_id"	INTEGER NOT NULL,
	"newsletter_name"	TEXT NOT NULL DEFAULT '',
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "newsletter_message_enforcements" (
	"_id"	INTEGER,
	"message_row_id"	INTEGER NOT NULL,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "newsletter_my_reaction_orphan_message" (
	"_id"	INTEGER,
	"chat_row_id"	INTEGER NOT NULL,
	"server_message_id"	INTEGER NOT NULL,
	"reaction_from_me"	TEXT,
	"reactions_from_me_ts"	INTEGER,
	"votes_from_me"	TEXT,
	"votes_from_me_ts"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "addon_message_media" (
	"_id"	INTEGER NOT NULL,
	"message_row_id"	INTEGER NOT NULL,
	"addon_message_index"	INTEGER NOT NULL,
	"chat_row_id"	INTEGER,
	"file_path"	TEXT,
	"file_size"	INTEGER,
	"media_key"	BLOB,
	"media_key_timestamp"	INTEGER,
	"width"	INTEGER,
	"height"	INTEGER,
	"direct_path"	TEXT,
	"message_url"	TEXT,
	"mime_type"	TEXT,
	"file_length"	INTEGER,
	"file_hash"	TEXT,
	"enc_file_hash"	TEXT,
	"partial_media_hash"	TEXT,
	"partial_media_enc_hash"	TEXT,
	"original_file_hash"	TEXT,
	"thumbnail"	TEXT,
	"thumbnail_direct_path"	TEXT,
	"thumbnail_hash"	TEXT,
	"enc_thumbnail_hash"	TEXT,
	"scans_sidecar"	BLOB,
	"transferred"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "business_message_forward_info" (
	"message_row_id"	INTEGER,
	"business_owner_jid_row_id"	INTEGER NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "bot_message_info" (
	"message_row_id"	INTEGER,
	"target_id"	TEXT,
	"message_state"	INTEGER DEFAULT 0,
	"invoker_jid_row_id"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_call_log" (
	"message_row_id"	INTEGER,
	"call_log_row_id"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "premium_message_info" (
	"message_row_id"	INTEGER,
	"campaign_id"	STRING NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "newsletter_subscribers" (
	"_id"	INTEGER,
	"chat_row_id"	INTEGER NOT NULL,
	"jid_row_id"	INTEGER,
	"display_name"	TEXT,
	"profile_picture_direct_path"	TEXT,
	"subscription_time"	INTEGER,
	"role"	INTEGER NOT NULL DEFAULT 0,
	"type_of_fetch"	INTEGER NOT NULL DEFAULT 0,
	"fetched_time"	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY("_id")
);
CREATE TABLE IF NOT EXISTS "status_message_info" (
	"message_row_id"	INTEGER,
	"status_distribution_mode"	INTEGER NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "bot_plugin_metadata" (
	"message_row_id"	INTEGER,
	"search_provider"	INTEGER,
	"plugin_type"	INTEGER,
	"thumbnail_cdn_url"	TEXT,
	"profile_photo_cdn_url"	TEXT,
	"search_provider_url"	TEXT,
	"reference_index"	INTEGER,
	"profile_photo_thumbnail"	BLOB,
	"search_query"	TEXT,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_opt_out" (
	"message_row_id"	INTEGER,
	"biz_opt_out_category"	INTEGER,
	"biz_opt_out_action"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_comment" (
	"_id"	INTEGER,
	"parent_message_row_id"	INTEGER,
	"message_row_id"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_orphan" (
	"_id"	INTEGER,
	"chat_row_id"	INTEGER,
	"from_me"	INTEGER,
	"key_id"	TEXT NOT NULL,
	"sender_jid_row_id"	INTEGER,
	"parent_chat_row_id"	INTEGER,
	"parent_from_me"	INTEGER,
	"parent_key_id"	TEXT,
	"parent_sender_jid_row_id"	INTEGER,
	"timestamp"	INTEGER,
	"orphan_message_data"	BLOB,
	"orphan_message_type"	INTEGER,
	"orphan_message_stanza_data"	BLOB,
	"orphan_message_reason"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "bcall_session" (
	"_id"	INTEGER,
	"session_id"	TEXT NOT NULL UNIQUE,
	"media_type"	INTEGER NOT NULL,
	"master_key"	BLOB NOT NULL,
	"caption"	TEXT,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "chat_ephemeral" (
	"chat_row_id"	INTEGER,
	"ephemeral_trigger"	INTEGER,
	"ephemeral_initiated_by_me"	BOOLEAN,
	PRIMARY KEY("chat_row_id")
);
CREATE TABLE IF NOT EXISTS "message_bcall_session" (
	"message_row_id"	INTEGER,
	"bcall_session_row_id"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "bot_chat_info" (
	"chat_row_id"	INTEGER,
	"pip_enabled"	BOOLEAN DEFAULT 0,
	"welcome_request_message_sent"	BOOLEAN,
	PRIMARY KEY("chat_row_id")
);
CREATE TABLE IF NOT EXISTS "status_crossposting_v3" (
	"status_message_row_id"	INTEGER,
	"crossposting_session_id"	TEXT,
	"crossposting_status_unique_id"	TEXT,
	"state"	INTEGER,
	"media_file_path"	TEXT,
	"direct_url_path"	TEXT,
	"destination"	INTEGER,
	PRIMARY KEY("status_message_row_id","destination")
);
CREATE TABLE IF NOT EXISTS "message_event" (
	"message_row_id"	INTEGER,
	"is_canceled"	INTEGER DEFAULT 0,
	"name"	TEXT NOT NULL,
	"description"	TEXT,
	"location_latitude"	REAL,
	"location_longitude"	REAL,
	"location_name"	TEXT,
	"location_address"	TEXT,
	"join_link"	TEXT,
	"start_time"	DATETIME NOT NULL,
	"chat_row_id"	INTEGER,
	"event_state"	INTEGER NOT NULL DEFAULT 0,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "data_sharing_disclosure_metadata" (
	"message_row_id"	INTEGER,
	"show_mm_disclosure"	BOOLEAN,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_quoted_call_log" (
	"message_row_id"	INTEGER,
	"video_call"	BOOLEAN,
	"call_result"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_add_on_event_response" (
	"message_add_on_row_id"	INTEGER,
	"response"	INTEGER DEFAULT 0,
	"sender_timestamp"	INTEGER NOT NULL,
	PRIMARY KEY("message_add_on_row_id")
);
CREATE TABLE IF NOT EXISTS "message_comment_parent" (
	"message_row_id"	INTEGER,
	"chat_row_id"	INTEGER,
	"number_of_comments"	INTEGER NOT NULL,
	"last_comment_ts"	INTEGER,
	"last_comment_message_row_id"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_newsletter_admin_invite" (
	"message_row_id"	INTEGER,
	"newsletter_jid_row_id"	INTEGER NOT NULL,
	"newsletter_name"	TEXT NOT NULL,
	"expiration"	INTEGER NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_reminder_setup" (
	"message_row_id"	INTEGER,
	"original_message_row_id"	INTEGER NOT NULL UNIQUE,
	"reminder_timestamp_ms"	INTEGER NOT NULL,
	"reminder_content"	TEXT NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_system_reminder_sent" (
	"message_row_id"	INTEGER,
	"original_message_row_id"	INTEGER NOT NULL UNIQUE,
	"original_reminder_content"	TEXT NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "call_unknown_caller" (
	"call_log_row_id"	INTEGER,
	PRIMARY KEY("call_log_row_id")
);
CREATE TABLE IF NOT EXISTS "reporting_token" (
	"message_row_id"	INTEGER,
	"reporting_tag"	BLOB NOT NULL,
	"reporting_token_content"	BLOB,
	"version"	INTEGER,
	"timestamp"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "scheduled_reminder_message" (
	"message_row_id"	INTEGER,
	"scheduled_reminder_timestamp_ms"	INTEGER NOT NULL,
	"chat_row_id"	INTEGER,
	PRIMARY KEY("message_row_id")
);
CREATE VIRTUAL TABLE labeled_messages_fts USING FTS3();
CREATE VIRTUAL TABLE message_ftsv2 USING FTS4(content, fts_jid, fts_namespace);
CREATE TABLE IF NOT EXISTS "message_ftsv2_content" (
	"docid"	INTEGER,
	"c0content"	,
	"c1fts_jid"	,
	"c2fts_namespace"	,
	PRIMARY KEY("docid")
);
CREATE TABLE IF NOT EXISTS "message_ftsv2_segments" (
	"blockid"	INTEGER,
	"block"	BLOB,
	PRIMARY KEY("blockid")
);
CREATE TABLE IF NOT EXISTS "message_ftsv2_segdir" (
	"level"	INTEGER,
	"idx"	INTEGER,
	"start_block"	INTEGER,
	"leaves_end_block"	INTEGER,
	"end_block"	INTEGER,
	"root"	BLOB,
	PRIMARY KEY("level","idx")
);
CREATE TABLE IF NOT EXISTS "message_ftsv2_docsize" (
	"docid"	INTEGER,
	"size"	BLOB,
	PRIMARY KEY("docid")
);
CREATE TABLE IF NOT EXISTS "message_ftsv2_stat" (
	"id"	INTEGER,
	"value"	BLOB,
	PRIMARY KEY("id")
);
CREATE TABLE IF NOT EXISTS "message_system_event_updates" (
	"message_row_id"	INTEGER,
	"event_message_row_id"	INTEGER NOT NULL,
	"event_name"	STRING NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "favorite" (
	"_id"	INTEGER,
	"jid_row_id"	INTEGER UNIQUE,
	"favorite_type"	INTEGER,
	"sort_order"	INTEGER,
	PRIMARY KEY("_id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "message_parent_association" (
	"message_row_id"	INTEGER,
	"parent_message_row_id"	INTEGER NOT NULL,
	"association_type"	INTEGER NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "bot_message_prompts" (
	"message_row_id"	INTEGER,
	"chat_row_id"	INTEGER UNIQUE,
	"prompts"	TEXT,
	"impression_logged"	INTEGER DEFAULT 0,
	PRIMARY KEY("message_row_id")
);
CREATE TABLE IF NOT EXISTS "message_fixed_content_placeholder" (
	"message_row_id"	INTEGER,
	"placeholder_type"	INTEGER NOT NULL,
	PRIMARY KEY("message_row_id")
);
CREATE UNIQUE INDEX IF NOT EXISTS "labeled_jid_index" ON "labeled_jid" (
	"label_id",
	"jid_row_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "labeled_jids_index" ON "labeled_jids" (
	"label_id",
	"jid"
);
CREATE UNIQUE INDEX IF NOT EXISTS "labeled_messages_index" ON "labeled_messages" (
	"label_id",
	"message_row_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "labels_index" ON "labels" (
	"label_name"
);
CREATE INDEX IF NOT EXISTS "call_log_ts_index" ON "call_log" (
	"timestamp"
);
CREATE INDEX IF NOT EXISTS "message_ui_elements_message_row_id_index" ON "message_ui_elements" (
	"message_row_id"
);
CREATE INDEX IF NOT EXISTS "message_ui_elements_element_type_index" ON "message_ui_elements" (
	"element_type"
);
CREATE UNIQUE INDEX IF NOT EXISTS "message_orphaned_edit_key_index" ON "message_orphaned_edit" (
	"key_id",
	"from_me",
	"chat_row_id",
	"sender_jid_row_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "message_media_interactive_annotation_index" ON "message_media_interactive_annotation" (
	"message_row_id",
	"sort_order"
);
CREATE UNIQUE INDEX IF NOT EXISTS "user_device_index" ON "user_device" (
	"user_jid_row_id",
	"device_jid_row_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "message_vcard_index" ON "message_vcard" (
	"message_row_id",
	"vcard"
);
CREATE INDEX IF NOT EXISTS "addon_message_media_message_row_id_index" ON "addon_message_media" (
	"message_row_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "missed_call_log_participants_key_index" ON "missed_call_log_participant" (
	"call_logs_row_id",
	"jid"
);
CREATE UNIQUE INDEX IF NOT EXISTS "message_media_interactive_annotation_vertex_index" ON "message_media_interactive_annotation_vertex" (
	"message_media_interactive_annotation_row_id",
	"sort_order"
);
CREATE UNIQUE INDEX IF NOT EXISTS "call_log_participant_key_index" ON "call_log_participant_v2" (
	"call_log_row_id",
	"jid_row_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "message_link_index" ON "message_link" (
	"message_row_id",
	"link_index"
);
CREATE UNIQUE INDEX IF NOT EXISTS "message_orphan_key_index" ON "message_orphan" (
	"chat_row_id",
	"from_me",
	"key_id",
	"sender_jid_row_id"
);
CREATE INDEX IF NOT EXISTS "message_orphan_parent_key_index" ON "message_orphan" (
	"parent_chat_row_id",
	"parent_from_me",
	"parent_key_id",
	"parent_sender_jid_row_id"
);
CREATE INDEX IF NOT EXISTS "message_orphan_message_type_index" ON "message_orphan" (
	"orphan_message_type"
);
CREATE INDEX IF NOT EXISTS "message_orphan_reason_index" ON "message_orphan" (
	"orphan_message_reason"
);
CREATE INDEX IF NOT EXISTS "bot_message_info_target_id_index" ON "bot_message_info" (
	"target_id"
);
CREATE INDEX IF NOT EXISTS "message_add_on_poll_vote_selected_option_message_add_on_row_id_index" ON "message_add_on_poll_vote_selected_option" (
	"message_add_on_row_id"
);
CREATE INDEX IF NOT EXISTS "message_poll_option_message_row_id_index" ON "message_poll_option" (
	"message_row_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "group_participant_device_index" ON "group_participant_device" (
	"group_participant_row_id",
	"device_jid_row_id"
);
CREATE INDEX IF NOT EXISTS "status_crossposting_v3_state_idx" ON "status_crossposting_v3" (
	"state"
);
CREATE UNIQUE INDEX IF NOT EXISTS "receipt_orphaned_index" ON "receipt_orphaned" (
	"chat_row_id",
	"from_me",
	"key_id",
	"receipt_device_jid_row_id",
	"receipt_recipient_jid_row_id",
	"status"
);
CREATE INDEX IF NOT EXISTS "message_event_name_index" ON "message_event" (
	"name"
);
CREATE INDEX IF NOT EXISTS "message_event_chat_row_id_and_start_time_index" ON "message_event" (
	"chat_row_id",
	"start_time"
);
CREATE UNIQUE INDEX IF NOT EXISTS "message_add_on_key_index" ON "message_add_on" (
	"chat_row_id",
	"from_me",
	"key_id",
	"sender_jid_row_id"
);
CREATE INDEX IF NOT EXISTS "message_add_on_status_index" ON "message_add_on" (
	"status"
);
CREATE INDEX IF NOT EXISTS "message_add_on_chat_status_index" ON "message_add_on" (
	"chat_row_id",
	"status"
);
CREATE INDEX IF NOT EXISTS "message_add_on_parent_message_row_id_index" ON "message_add_on" (
	"parent_message_row_id"
);
CREATE INDEX IF NOT EXISTS "message_add_on_expiry_timestamp_index" ON "message_add_on" (
	"expiry_timestamp"
);
CREATE UNIQUE INDEX IF NOT EXISTS "message_add_on_orphan_key_index" ON "message_add_on_orphan" (
	"chat_row_id",
	"from_me",
	"key_id",
	"sender_jid_row_id"
);
CREATE INDEX IF NOT EXISTS "message_add_on_orphan_parent_key_index" ON "message_add_on_orphan" (
	"parent_chat_row_id",
	"parent_from_me",
	"parent_key_id",
	"parent_sender_jid_row_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "group_participant_user_index" ON "group_participant_user" (
	"group_jid_row_id",
	"user_jid_row_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "mentions_index" ON "message_mentions" (
	"message_row_id",
	"jid_row_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "jid_key_new_index" ON "jid" (
	"user",
	"server",
	"agent",
	"device",
	"type"
);
CREATE UNIQUE INDEX IF NOT EXISTS "jid_raw_string_index" ON "jid" (
	"raw_string"
);
CREATE INDEX IF NOT EXISTS "jid_lid_map_jid_index" ON "jid_map" (
	"jid_row_id"
);
CREATE INDEX IF NOT EXISTS "integrator_opt_in_index" ON "integrator_display_name" (
	"opt_in_status"
);
CREATE UNIQUE INDEX IF NOT EXISTS "message_quoted_vcard_index" ON "message_quoted_vcard" (
	"message_row_id",
	"vcard"
);
CREATE INDEX IF NOT EXISTS "chat_group_type_index" ON "chat" (
	"group_type"
);
CREATE UNIQUE INDEX IF NOT EXISTS "user_device_info_index" ON "user_device_info" (
	"user_jid_row_id"
);
CREATE INDEX IF NOT EXISTS "message_view_once_media_state_index" ON "message_view_once_media" (
	"state"
);
CREATE UNIQUE INDEX IF NOT EXISTS "group_notification_version_index" ON "group_notification_version" (
	"group_jid_row_id"
);
CREATE INDEX IF NOT EXISTS "group_past_participant_user_timestamp_index" ON "group_past_participant_user" (
	"timestamp"
);
CREATE UNIQUE INDEX IF NOT EXISTS "group_past_participant_user_index" ON "group_past_participant_user" (
	"group_jid_row_id",
	"user_jid_row_id"
);
CREATE INDEX IF NOT EXISTS "scheduled_reminder_message_chat_row_id_index" ON "scheduled_reminder_message" (
	"chat_row_id"
);
CREATE INDEX IF NOT EXISTS "scheduled_reminder_message_timestamp_index" ON "scheduled_reminder_message" (
	"scheduled_reminder_timestamp_ms"
);
CREATE UNIQUE INDEX IF NOT EXISTS "quoted_mentions_index" ON "message_quoted_mentions" (
	"message_row_id",
	"jid_row_id"
);
CREATE INDEX IF NOT EXISTS "joinable_call_log_group_jid_row_id_index" ON "joinable_call_log" (
	"group_jid_row_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "joinable_call_log_call_id_index" ON "joinable_call_log" (
	"call_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "frequent_index" ON "frequent" (
	"jid_row_id",
	"type"
);
CREATE INDEX IF NOT EXISTS "message_details_author_device_jid_index" ON "message_details" (
	"author_device_jid"
);
CREATE INDEX IF NOT EXISTS "reporting_token_timestamp_index" ON "reporting_token" (
	"timestamp"
);
CREATE INDEX IF NOT EXISTS "backup_changes_operation_index" ON "backup_changes" (
	"operation",
	"table_name",
	"table_row_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "message_payment_transaction_id_index" ON "pay_transaction" (
	"id"
);
CREATE INDEX IF NOT EXISTS "message_add_on_event_response_index" ON "message_add_on_event_response" (
	"response"
);
CREATE INDEX IF NOT EXISTS "message_template_button_index" ON "message_template_button" (
	"message_row_id"
);
CREATE INDEX IF NOT EXISTS "receipt_device_table_device_index" ON "receipt_device" (
	"receipt_device_jid_row_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "receipt_device_index" ON "receipt_device" (
	"message_row_id",
	"receipt_device_jid_row_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "receipt_user_index" ON "receipt_user" (
	"message_row_id",
	"receipt_user_jid_row_id"
);
CREATE INDEX IF NOT EXISTS "message_bot_feedback_index" ON "message_bot_feedback" (
	"bot_feedback_key_remote_jid",
	"bot_feedback_key_from_me",
	"bot_feedback_key_id"
);
CREATE INDEX IF NOT EXISTS "crossposting_session_id_index" ON "status_crossposting" (
	"crossposting_session_id"
);
CREATE INDEX IF NOT EXISTS "crossposting_state_index" ON "status_crossposting" (
	"state"
);
CREATE INDEX IF NOT EXISTS "deleted_chat_job_index" ON "deleted_chat_job" (
	"chat_row_id",
	"_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "call_log_key_index" ON "call_log" (
	"jid_row_id",
	"from_me",
	"call_id",
	"transaction_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "message_key_index" ON "message" (
	"chat_row_id",
	"from_me",
	"key_id",
	"sender_jid_row_id"
);
CREATE INDEX IF NOT EXISTS "message_sort_id_index" ON "message" (
	"sort_id"
);
CREATE INDEX IF NOT EXISTS "message_starred_index" ON "message" (
	"starred"
);
CREATE INDEX IF NOT EXISTS "message_type_chat_index" ON "message" (
	"chat_row_id",
	"message_type"
);
CREATE INDEX IF NOT EXISTS "message_chat_id_index" ON "message" (
	"chat_row_id",
	"_id"
);
CREATE INDEX IF NOT EXISTS "message_type_index" ON "message" (
	"message_type"
);
CREATE INDEX IF NOT EXISTS "message_chat_sort_id_index" ON "message" (
	"chat_row_id",
	"sort_id"
);
CREATE INDEX IF NOT EXISTS "message_starred_sort_id_index" ON "message" (
	"starred",
	"sort_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "message_media_vcard_count_index" ON "message_media_vcard_count" (
	"message_row_id"
);
CREATE INDEX IF NOT EXISTS "message_parent_association_parent_message_row_id_and_association_type_index" ON "message_parent_association" (
	"parent_message_row_id",
	"association_type"
);
CREATE INDEX IF NOT EXISTS "mms_thumbnail_metadata_transferred_index" ON "mms_thumbnail_metadata" (
	"transferred"
);
CREATE UNIQUE INDEX IF NOT EXISTS "call_link_token_index" ON "call_link" (
	"token"
);
CREATE UNIQUE INDEX IF NOT EXISTS "message_add_on_receipt_device_index" ON "message_add_on_receipt_device" (
	"message_add_on_row_id",
	"receipt_device_jid_row_id"
);
CREATE INDEX IF NOT EXISTS "message_add_on_receipt_device_jid_index" ON "message_add_on_receipt_device" (
	"receipt_device_jid_row_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "message_comment_parent_message_row_id_unique_index" ON "message_comment" (
	"parent_message_row_id",
	"message_row_id"
);
CREATE INDEX IF NOT EXISTS "message_comment_message_row_id_index" ON "message_comment" (
	"message_row_id"
);
CREATE INDEX IF NOT EXISTS "message_ephemeral_expire_timestamp_index" ON "message_ephemeral" (
	"expire_timestamp"
);
CREATE INDEX IF NOT EXISTS "message_add_on_pin_in_chat_state_index" ON "message_add_on_pin_in_chat" (
	"pin_in_chat_state"
);
CREATE UNIQUE INDEX IF NOT EXISTS "missed_call_logs_key_index" ON "missed_call_logs" (
	"message_row_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "message_edit_info_index" ON "message_edit_info" (
	"original_key_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "message_vcard_jid_index" ON "message_vcard_jid" (
	"vcard_jid_row_id",
	"vcard_row_id",
	"message_row_id"
);
CREATE INDEX IF NOT EXISTS "sort_order_index" ON "favorite" (
	"sort_order"
);
CREATE INDEX IF NOT EXISTS "message_media_hash_index" ON "message_media" (
	"file_hash"
);
CREATE INDEX IF NOT EXISTS "message_media_chat_index" ON "message_media" (
	"chat_row_id"
);
CREATE INDEX IF NOT EXISTS "message_media_original_file_hash_index" ON "message_media" (
	"original_file_hash"
);
CREATE UNIQUE INDEX IF NOT EXISTS "messages_thumbnail_key_index" ON "message_thumbnails" (
	"key_remote_jid",
	"key_from_me",
	"key_id"
);
CREATE INDEX IF NOT EXISTS "message_parent_last_comment_index" ON "message_comment_parent" (
	"chat_row_id",
	"last_comment_message_row_id"
);
CREATE INDEX IF NOT EXISTS "scheduled_calls_chat_row_id_index" ON "scheduled_calls" (
	"key_chat_row_id",
	"scheduled_timestamp",
	"is_upcoming"
);
CREATE INDEX IF NOT EXISTS "scheduled_calls_key_id_index" ON "scheduled_calls" (
	"key_chat_row_id",
	"key_id"
);
CREATE INDEX IF NOT EXISTS "scheduled_calls_timestamp_index_v2" ON "scheduled_calls" (
	"is_upcoming",
	"scheduled_timestamp"
);
CREATE INDEX IF NOT EXISTS "scheduled_calls_call_log_row_id_index" ON "scheduled_calls" (
	"call_log_row_id"
);
CREATE INDEX IF NOT EXISTS "message_newsletter_admin_invite_newsletter_jid_row_id_index" ON "message_newsletter_admin_invite" (
	"newsletter_jid_row_id"
);
CREATE INDEX IF NOT EXISTS "message_system_chat_participant_index" ON "message_system_chat_participant" (
	"message_row_id"
);
CREATE INDEX IF NOT EXISTS "parent_group_participants_parent_jid_index" ON "parent_group_participants" (
	"parent_group_jid_row_id"
);
CREATE INDEX IF NOT EXISTS "newsletter_linked_account_chat_index" ON "newsletter_linked_account" (
	"chat_row_id"
);
CREATE INDEX IF NOT EXISTS "newsletter_subscribers_by_type_index" ON "newsletter_subscribers" (
	"chat_row_id",
	"type_of_fetch"
);
CREATE INDEX IF NOT EXISTS "newsletter_membership_index" ON "newsletter" (
	"membership"
);
CREATE INDEX IF NOT EXISTS "newsletter_code_index" ON "newsletter" (
	"invite_code"
);
CREATE UNIQUE INDEX IF NOT EXISTS "newsletter_message_index" ON "newsletter_message" (
	"chat_row_id",
	"server_message_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "newsletter_my_reaction_orphan_message_index" ON "newsletter_my_reaction_orphan_message" (
	"chat_row_id",
	"server_message_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "newsletter_message_reaction_index" ON "newsletter_message_reaction" (
	"message_row_id",
	"reaction"
);
CREATE INDEX IF NOT EXISTS "agent_device_index" ON "agent_devices" (
	"device"
);
CREATE INDEX IF NOT EXISTS "priority_inbox_chat_row_index" ON "priority_inbox" (
	"chat_row_id"
);
CREATE INDEX IF NOT EXISTS "priority_inbox_time_created_index" ON "priority_inbox" (
	"time_created"
);
CREATE INDEX IF NOT EXISTS "priority_inbox_score_index" ON "priority_inbox" (
	"priority_score"
);
CREATE INDEX IF NOT EXISTS "chat_assignee_index" ON "agent_chat_assignment" (
	"agent_id"
);
CREATE INDEX IF NOT EXISTS "attachments_quick_reply_id_index" ON "quick_reply_attachments" (
	"quick_reply_id"
);
CREATE INDEX IF NOT EXISTS "chat_hidden_index" ON "chat" (
	"hidden"
);
CREATE INDEX IF NOT EXISTS "user_device_info_account_type_index" ON "user_device_info" (
	"account_encryption_type"
);
CREATE TRIGGER message_media_bd_for_message_media_interactive_annotation_trigger BEFORE DELETE ON message_media BEGIN DELETE FROM message_media_interactive_annotation WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER call_log_bd_for_call_log_participant_v2_trigger BEFORE DELETE ON call_log BEGIN DELETE FROM call_log_participant_v2 WHERE call_log_row_id=old._id; END;
CREATE TRIGGER chat_bd_for_message_link_trigger BEFORE DELETE ON chat BEGIN DELETE FROM message_link WHERE chat_row_id=old._id; END;
CREATE TRIGGER group_participant_user_bd_for_group_participant_device_trigger BEFORE DELETE ON group_participant_user BEGIN DELETE FROM group_participant_device WHERE group_participant_row_id=old._id; END;
CREATE TRIGGER message_media_interactive_annotation_bd_for_message_media_interactive_annotation_vertex_trigger BEFORE DELETE ON message_media_interactive_annotation BEGIN DELETE FROM message_media_interactive_annotation_vertex WHERE message_media_interactive_annotation_row_id=old._id; END;
CREATE TRIGGER message_quoted_bd_for_message_quoted_group_invite_trigger BEFORE DELETE ON message_quoted BEGIN DELETE FROM message_quoted_group_invite WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_quoted_bd_for_message_quoted_mentions_trigger BEFORE DELETE ON message_quoted BEGIN DELETE FROM message_quoted_mentions WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_quoted_bd_for_message_quoted_vcard_trigger BEFORE DELETE ON message_quoted BEGIN DELETE FROM message_quoted_vcard WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_template_bd_for_message_template_button_trigger BEFORE DELETE ON message_template BEGIN DELETE FROM message_template_button WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_vcard_bd_for_message_vcard_jid_trigger BEFORE DELETE ON message_vcard BEGIN DELETE FROM message_vcard_jid WHERE vcard_row_id=old._id; END;
CREATE TRIGGER missed_call_logs_bd_for_missed_call_log_participant_trigger BEFORE DELETE ON missed_call_logs BEGIN DELETE FROM missed_call_log_participant WHERE call_logs_row_id=old._id; END;
CREATE TRIGGER quick_replies_bd_for_quick_reply_attachments_trigger BEFORE DELETE ON quick_replies BEGIN DELETE FROM quick_reply_attachments WHERE quick_reply_id=old._id; END;
CREATE TRIGGER quick_replies_bd_for_quick_reply_keywords_trigger BEFORE DELETE ON quick_replies BEGIN DELETE FROM quick_reply_keywords WHERE quick_reply_id=old._id; END;
CREATE TRIGGER quick_replies_bd_for_quick_reply_usage_trigger BEFORE DELETE ON quick_replies BEGIN DELETE FROM quick_reply_usage WHERE quick_reply_id=old._id; END;
CREATE TRIGGER message_quoted_bd_for_message_quoted_media_trigger BEFORE DELETE ON message_quoted BEGIN DELETE FROM message_quoted_media WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_media_bd_for_message_media_vcard_count_trigger BEFORE DELETE ON message_media BEGIN DELETE FROM message_media_vcard_count WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_quoted_bd_for_message_quoted_location_trigger BEFORE DELETE ON message_quoted BEGIN DELETE FROM message_quoted_location WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_quoted_bd_for_message_quoted_text_trigger BEFORE DELETE ON message_quoted BEGIN DELETE FROM message_quoted_text WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_payment_status_update_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_payment_status_update WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_payment_transaction_reminder_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_payment_transaction_reminder WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_payment_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_payment WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_system_block_contact_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_block_contact WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_system_chat_participant_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_chat_participant WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_system_device_change_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_device_change WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_system_group_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_group WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_system_number_change_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_number_change WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_system_photo_change_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_photo_change WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_system_value_change_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_value_change WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_system_ephemeral_setting_not_applied_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_ephemeral_setting_not_applied WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_system_initial_privacy_provider_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_initial_privacy_provider WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_system_business_state_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_business_state WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_quoted_bd_for_message_quoted_payment_invite_trigger BEFORE DELETE ON message_quoted BEGIN DELETE FROM message_quoted_payment_invite WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_system_payment_invite_setup_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_payment_invite_setup WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER payment_background_bd_for_payment_background_order_trigger BEFORE DELETE ON payment_background BEGIN DELETE FROM payment_background_order WHERE background_id=old.background_id; END;
CREATE TRIGGER call_log_bd_for_joinable_call_log_trigger BEFORE DELETE ON call_log BEGIN DELETE FROM joinable_call_log WHERE call_log_row_id=old._id; END;
CREATE TRIGGER message_system_bd_for_message_system_linked_group_call_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_linked_group_call WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_add_on_bd_for_message_add_on_reaction_trigger BEFORE DELETE ON message_add_on BEGIN DELETE FROM message_add_on_reaction WHERE message_add_on_row_id=old._id; END;
CREATE TRIGGER message_add_on_bd_for_message_add_on_receipt_device_trigger BEFORE DELETE ON message_add_on BEGIN DELETE FROM message_add_on_receipt_device WHERE message_add_on_row_id=old._id; END;
CREATE TRIGGER message_quoted_bd_for_message_quoted_blank_reply_trigger BEFORE DELETE ON message_quoted BEGIN DELETE FROM message_quoted_blank_reply WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_system_community_link_changed_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_community_link_changed WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_system_sibling_group_link_change_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_sibling_group_link_change WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER chat_bd_for_message_add_on_orphan_trigger BEFORE DELETE ON chat BEGIN DELETE FROM message_add_on_orphan WHERE parent_chat_row_id=old._id; END;
CREATE TRIGGER message_add_on_bd_for_message_add_on_poll_vote_selected_option_trigger BEFORE DELETE ON message_add_on BEGIN DELETE FROM message_add_on_poll_vote_selected_option WHERE message_add_on_row_id=old._id; END;
CREATE TRIGGER message_add_on_bd_for_message_add_on_poll_vote_trigger BEFORE DELETE ON message_add_on BEGIN DELETE FROM message_add_on_poll_vote WHERE message_add_on_row_id=old._id; END;
CREATE TRIGGER message_poll_bd_for_message_poll_option_trigger BEFORE DELETE ON message_poll BEGIN DELETE FROM message_poll_option WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_bd_for_agent_message_attribution_trigger BEFORE DELETE ON message BEGIN DELETE FROM agent_message_attribution WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_audio_data_trigger BEFORE DELETE ON message BEGIN DELETE FROM audio_data WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_add_on_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_add_on WHERE parent_message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_broadcast_ephemeral_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_broadcast_ephemeral WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_ephemeral_setting_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_ephemeral_setting WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_ephemeral_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_ephemeral WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_external_ad_content_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_external_ad_content WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_forwarded_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_forwarded WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_ftsv2_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_ftsv2 WHERE docid=old._id; END;
CREATE TRIGGER message_bd_for_message_future_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_future WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_group_invite_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_group_invite WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_link_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_link WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_location_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_location WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_media_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_media WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_mentions_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_mentions WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_order_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_order WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_payment_invite_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_payment_invite WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_poll_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_poll WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_privacy_state_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_privacy_state WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_product_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_product WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_quoted_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_quoted WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_rating_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_rating WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_revoked_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_revoked WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_send_count_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_send_count WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_status_psa_campaign_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_status_psa_campaign WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_streaming_sidecar_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_streaming_sidecar WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_system_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_system WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_template_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_template WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_text_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_text WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_thumbnail_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_thumbnail WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_ui_elements_reply_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_ui_elements_reply WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_ui_elements_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_ui_elements WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_vcard_jid_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_vcard_jid WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_vcard_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_vcard WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_view_once_media_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_view_once_media WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_messages_hydrated_four_row_template_trigger BEFORE DELETE ON message BEGIN DELETE FROM messages_hydrated_four_row_template WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_missed_call_logs_trigger BEFORE DELETE ON message BEGIN DELETE FROM missed_call_logs WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_mms_thumbnail_metadata_trigger BEFORE DELETE ON message BEGIN DELETE FROM mms_thumbnail_metadata WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_played_self_receipt_trigger BEFORE DELETE ON message BEGIN DELETE FROM played_self_receipt WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_receipt_device_trigger BEFORE DELETE ON message BEGIN DELETE FROM receipt_device WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_receipt_user_trigger BEFORE DELETE ON message BEGIN DELETE FROM receipt_user WHERE message_row_id=old._id; END;
CREATE TRIGGER message_quoted_bd_for_message_quoted_order_trigger BEFORE DELETE ON message_quoted BEGIN DELETE FROM message_quoted_order WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_quoted_bd_for_message_quoted_product_trigger BEFORE DELETE ON message_quoted BEGIN DELETE FROM message_quoted_product WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_quoted_bd_for_message_quoted_ui_elements_reply_trigger BEFORE DELETE ON message_quoted BEGIN DELETE FROM message_quoted_ui_elements_reply WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_quoted_bd_for_message_quoted_ui_elements_trigger BEFORE DELETE ON message_quoted BEGIN DELETE FROM message_quoted_ui_elements WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_quoted_bd_for_message_template_quoted_trigger BEFORE DELETE ON message_quoted BEGIN DELETE FROM message_template_quoted WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_add_on_bd_for_message_add_on_keep_in_chat_trigger BEFORE DELETE ON message_add_on BEGIN DELETE FROM message_add_on_keep_in_chat WHERE message_add_on_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_secret_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_secret WHERE message_row_id=old._id; END;
CREATE TRIGGER message_system_bd_for_message_system_group_with_parent_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_group_with_parent WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER chat_bd_for_community_chat_trigger BEFORE DELETE ON chat BEGIN DELETE FROM community_chat WHERE chat_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_details_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_details WHERE message_row_id=old._id; END;
CREATE TRIGGER message_system_bd_for_message_system_chat_assignment_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_chat_assignment WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_bd_for_message_edit_info_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_edit_info WHERE message_row_id=old._id; END;
CREATE TRIGGER message_system_bd_for_message_system_with_group_nodes_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_with_group_nodes WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_add_on_bd_for_message_add_on_pin_in_chat_trigger BEFORE DELETE ON message_add_on BEGIN DELETE FROM message_add_on_pin_in_chat WHERE message_add_on_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_scheduled_call_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_scheduled_call WHERE message_row_id=old._id; END;
CREATE TRIGGER message_system_bd_for_message_system_scheduled_call_start_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_scheduled_call_start WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_bd_for_suggested_replies_trigger BEFORE DELETE ON message BEGIN DELETE FROM suggested_replies WHERE message_row_id=old._id OR customer_message_row_id=old._id; END;
CREATE TRIGGER chat_bd_for_newsletter_linked_account_trigger BEFORE DELETE ON chat BEGIN DELETE FROM newsletter_linked_account WHERE chat_row_id=old._id; END;
CREATE TRIGGER chat_bd_for_newsletter_trigger BEFORE DELETE ON chat BEGIN DELETE FROM newsletter WHERE chat_row_id=old._id; END;
CREATE TRIGGER message_bd_for_newsletter_message_trigger BEFORE DELETE ON message BEGIN DELETE FROM newsletter_message WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_status_crossposting_trigger BEFORE DELETE ON message BEGIN DELETE FROM status_crossposting WHERE status_message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_suggest_as_you_type_trigger BEFORE DELETE ON message BEGIN DELETE FROM suggest_as_you_type WHERE message_row_id=old._id; END;
CREATE TRIGGER message_add_on_bd_for_message_add_on_scheduled_call_edit_trigger BEFORE DELETE ON message_add_on BEGIN DELETE FROM message_add_on_scheduled_call_edit WHERE message_add_on_row_id=old._id; END;
CREATE TRIGGER message_system_bd_for_message_system_group_auto_restrict_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_group_auto_restrict WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_bd_for_newsletter_message_reaction_trigger BEFORE DELETE ON message BEGIN DELETE FROM newsletter_message_reaction WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_forwarded_newsletter_message_info_trigger BEFORE DELETE ON message BEGIN DELETE FROM forwarded_newsletter_message_info WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_bot_feedback_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_bot_feedback WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_newsletter_message_enforcements_trigger BEFORE DELETE ON message BEGIN DELETE FROM newsletter_message_enforcements WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_addon_message_media_trigger BEFORE DELETE ON message BEGIN DELETE FROM addon_message_media WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_business_message_forward_info_trigger BEFORE DELETE ON message BEGIN DELETE FROM business_message_forward_info WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_bot_message_info_trigger BEFORE DELETE ON message BEGIN DELETE FROM bot_message_info WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_call_log_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_call_log WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_premium_message_info_trigger BEFORE DELETE ON message BEGIN DELETE FROM premium_message_info WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_status_message_info_trigger BEFORE DELETE ON message BEGIN DELETE FROM status_message_info WHERE message_row_id=old._id; END;
CREATE TRIGGER newsletter_bd_for_newsletter_subscribers_trigger BEFORE DELETE ON newsletter BEGIN DELETE FROM newsletter_subscribers WHERE chat_row_id=old.chat_row_id; END;
CREATE TRIGGER chat_bd_for_message_orphan_trigger BEFORE DELETE ON chat BEGIN DELETE FROM message_orphan WHERE parent_chat_row_id=old._id; END;
CREATE TRIGGER message_bd_for_bot_plugin_metadata_trigger BEFORE DELETE ON message BEGIN DELETE FROM bot_plugin_metadata WHERE message_row_id=old._id; END;
CREATE TRIGGER message_system_bd_for_message_system_opt_out_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_opt_out WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER chat_bd_for_chat_ephemeral_trigger BEFORE DELETE ON chat BEGIN DELETE FROM chat_ephemeral WHERE chat_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_bcall_session_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_bcall_session WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_comment_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_comment WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_status_crossposting_v3_trigger BEFORE DELETE ON message BEGIN DELETE FROM status_crossposting_v3 WHERE status_message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_event_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_event WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_data_sharing_disclosure_metadata_trigger BEFORE DELETE ON message BEGIN DELETE FROM data_sharing_disclosure_metadata WHERE message_row_id=old._id; END;
CREATE TRIGGER chat_bd_for_bot_chat_info_trigger BEFORE DELETE ON chat BEGIN DELETE FROM bot_chat_info WHERE chat_row_id = old._id; END;
CREATE TRIGGER message_quoted_bd_for_message_quoted_call_log_trigger BEFORE DELETE ON message_quoted BEGIN DELETE FROM message_quoted_call_log WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_add_on_bd_for_message_add_on_event_response_trigger BEFORE DELETE ON message_add_on BEGIN DELETE FROM message_add_on_event_response WHERE message_add_on_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_comment_parent_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_comment_parent WHERE message_row_id=old._id; END;
CREATE TRIGGER call_log_bd_for_call_unknown_caller_trigger BEFORE DELETE ON call_log BEGIN DELETE FROM call_unknown_caller WHERE call_log_row_id=OLD._id; END;
CREATE TRIGGER message_bd_for_message_newsletter_admin_invite_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_newsletter_admin_invite WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_template_button_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_template_button WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_reporting_token_trigger BEFORE DELETE ON message BEGIN DELETE FROM reporting_token WHERE message_row_id=old._id; END;
CREATE TRIGGER message_system_bd_for_message_system_reminder_sent_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_reminder_sent WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_system_bd_for_message_system_reminder_setup_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_reminder_setup WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_bd_for_scheduled_reminder_message_trigger BEFORE DELETE ON message BEGIN DELETE FROM scheduled_reminder_message WHERE message_row_id=old._id; END;
CREATE TRIGGER agent_chat_assignment_delete_for_backup_changes_trigger AFTER DELETE ON agent_chat_assignment BEGIN DELETE FROM backup_changes WHERE (table_name = 'agent_chat_assignment') AND (table_row_id = OLD.jid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'agent_chat_assignment', OLD.jid_row_id);  END;
CREATE TRIGGER agent_chat_assignment_insert_for_backup_changes_trigger AFTER INSERT ON agent_chat_assignment BEGIN DELETE FROM backup_changes WHERE (table_name = 'agent_chat_assignment') AND (table_row_id = NEW.jid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'agent_chat_assignment', NEW.jid_row_id);  END;
CREATE TRIGGER agent_chat_assignment_update_for_backup_changes_trigger AFTER UPDATE ON agent_chat_assignment BEGIN DELETE FROM backup_changes WHERE (table_name = 'agent_chat_assignment') AND (table_row_id = NEW.jid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'agent_chat_assignment', NEW.jid_row_id);  END;
CREATE TRIGGER agent_devices_delete_for_backup_changes_trigger AFTER DELETE ON agent_devices BEGIN DELETE FROM backup_changes WHERE (table_name = 'agent_devices') AND (table_row_id = OLD.rowid) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'agent_devices', OLD.rowid);  END;
CREATE TRIGGER agent_devices_insert_for_backup_changes_trigger AFTER INSERT ON agent_devices BEGIN DELETE FROM backup_changes WHERE (table_name = 'agent_devices') AND (table_row_id = NEW.rowid) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'agent_devices', NEW.rowid);  END;
CREATE TRIGGER agent_devices_update_for_backup_changes_trigger AFTER UPDATE ON agent_devices BEGIN DELETE FROM backup_changes WHERE (table_name = 'agent_devices') AND (table_row_id = NEW.rowid) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'agent_devices', NEW.rowid);  END;
CREATE TRIGGER agent_message_attribution_delete_for_backup_changes_trigger AFTER DELETE ON agent_message_attribution BEGIN DELETE FROM backup_changes WHERE (table_name = 'agent_message_attribution') AND (table_row_id = OLD.message_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'agent_message_attribution', OLD.message_row_id);  END;
CREATE TRIGGER agent_message_attribution_insert_for_backup_changes_trigger AFTER INSERT ON agent_message_attribution BEGIN DELETE FROM backup_changes WHERE (table_name = 'agent_message_attribution') AND (table_row_id = NEW.message_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'agent_message_attribution', NEW.message_row_id);  END;
CREATE TRIGGER agent_message_attribution_update_for_backup_changes_trigger AFTER UPDATE ON agent_message_attribution BEGIN DELETE FROM backup_changes WHERE (table_name = 'agent_message_attribution') AND (table_row_id = NEW.message_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'agent_message_attribution', NEW.message_row_id);  END;
CREATE TRIGGER away_messages_delete_for_backup_changes_trigger AFTER DELETE ON away_messages BEGIN DELETE FROM backup_changes WHERE (table_name = 'away_messages') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'away_messages', OLD._id);  END;
CREATE TRIGGER away_messages_insert_for_backup_changes_trigger AFTER INSERT ON away_messages BEGIN DELETE FROM backup_changes WHERE (table_name = 'away_messages') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'away_messages', NEW._id);  END;
CREATE TRIGGER away_messages_update_for_backup_changes_trigger AFTER UPDATE ON away_messages BEGIN DELETE FROM backup_changes WHERE (table_name = 'away_messages') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'away_messages', NEW._id);  END;
CREATE TRIGGER call_link_delete_for_backup_changes_trigger AFTER DELETE ON call_link BEGIN DELETE FROM backup_changes WHERE (table_name = 'call_link') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'call_link', OLD._id);  END;
CREATE TRIGGER call_link_insert_for_backup_changes_trigger AFTER INSERT ON call_link BEGIN DELETE FROM backup_changes WHERE (table_name = 'call_link') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'call_link', NEW._id);  END;
CREATE TRIGGER call_link_update_for_backup_changes_trigger AFTER UPDATE ON call_link BEGIN DELETE FROM backup_changes WHERE (table_name = 'call_link') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'call_link', NEW._id);  END;
CREATE TRIGGER call_log_delete_for_backup_changes_trigger AFTER DELETE ON call_log BEGIN DELETE FROM backup_changes WHERE (table_name = 'call_log') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'call_log', OLD._id);  END;
CREATE TRIGGER call_log_insert_for_backup_changes_trigger AFTER INSERT ON call_log BEGIN DELETE FROM backup_changes WHERE (table_name = 'call_log') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'call_log', NEW._id);  END;
CREATE TRIGGER call_log_participant_v2_delete_for_backup_changes_trigger AFTER DELETE ON call_log_participant_v2 BEGIN DELETE FROM backup_changes WHERE (table_name = 'call_log_participant_v2') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'call_log_participant_v2', OLD._id);  END;
CREATE TRIGGER call_log_participant_v2_insert_for_backup_changes_trigger AFTER INSERT ON call_log_participant_v2 BEGIN DELETE FROM backup_changes WHERE (table_name = 'call_log_participant_v2') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'call_log_participant_v2', NEW._id);  END;
CREATE TRIGGER call_log_participant_v2_update_for_backup_changes_trigger AFTER UPDATE ON call_log_participant_v2 BEGIN DELETE FROM backup_changes WHERE (table_name = 'call_log_participant_v2') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'call_log_participant_v2', NEW._id);  END;
CREATE TRIGGER call_log_update_for_backup_changes_trigger AFTER UPDATE ON call_log BEGIN DELETE FROM backup_changes WHERE (table_name = 'call_log') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'call_log', NEW._id);  END;
CREATE TRIGGER chat_delete_for_backup_changes_trigger AFTER DELETE ON chat BEGIN DELETE FROM backup_changes WHERE (table_name = 'chat') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'chat', OLD._id);  END;
CREATE TRIGGER chat_insert_for_backup_changes_trigger AFTER INSERT ON chat BEGIN DELETE FROM backup_changes WHERE (table_name = 'chat') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'chat', NEW._id);  END;
CREATE TRIGGER chat_update_for_backup_changes_trigger AFTER UPDATE ON chat BEGIN DELETE FROM backup_changes WHERE (table_name = 'chat') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'chat', NEW._id);  END;
CREATE TRIGGER community_chat_delete_for_backup_changes_trigger AFTER DELETE ON community_chat BEGIN DELETE FROM backup_changes WHERE (table_name = 'community_chat') AND (table_row_id = OLD.chat_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'community_chat', OLD.chat_row_id);  END;
CREATE TRIGGER community_chat_insert_for_backup_changes_trigger AFTER INSERT ON community_chat BEGIN DELETE FROM backup_changes WHERE (table_name = 'community_chat') AND (table_row_id = NEW.chat_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'community_chat', NEW.chat_row_id);  END;
CREATE TRIGGER community_chat_update_for_backup_changes_trigger AFTER UPDATE ON community_chat BEGIN DELETE FROM backup_changes WHERE (table_name = 'community_chat') AND (table_row_id = NEW.chat_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'community_chat', NEW.chat_row_id);  END;
CREATE TRIGGER frequent_delete_for_backup_changes_trigger AFTER DELETE ON frequent BEGIN DELETE FROM backup_changes WHERE (table_name = 'frequent') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'frequent', OLD._id);  END;
CREATE TRIGGER frequent_insert_for_backup_changes_trigger AFTER INSERT ON frequent BEGIN DELETE FROM backup_changes WHERE (table_name = 'frequent') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'frequent', NEW._id);  END;
CREATE TRIGGER frequent_update_for_backup_changes_trigger AFTER UPDATE ON frequent BEGIN DELETE FROM backup_changes WHERE (table_name = 'frequent') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'frequent', NEW._id);  END;
CREATE TRIGGER group_notification_version_delete_for_backup_changes_trigger AFTER DELETE ON group_notification_version BEGIN DELETE FROM backup_changes WHERE (table_name = 'group_notification_version') AND (table_row_id = OLD.group_jid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'group_notification_version', OLD.group_jid_row_id);  END;
CREATE TRIGGER group_notification_version_insert_for_backup_changes_trigger AFTER INSERT ON group_notification_version BEGIN DELETE FROM backup_changes WHERE (table_name = 'group_notification_version') AND (table_row_id = NEW.group_jid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'group_notification_version', NEW.group_jid_row_id);  END;
CREATE TRIGGER group_notification_version_update_for_backup_changes_trigger AFTER UPDATE ON group_notification_version BEGIN DELETE FROM backup_changes WHERE (table_name = 'group_notification_version') AND (table_row_id = NEW.group_jid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'group_notification_version', NEW.group_jid_row_id);  END;
CREATE TRIGGER group_participant_device_delete_for_backup_changes_trigger AFTER DELETE ON group_participant_device BEGIN DELETE FROM backup_changes WHERE (table_name = 'group_participant_device') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'group_participant_device', OLD._id);  END;
CREATE TRIGGER group_participant_device_insert_for_backup_changes_trigger AFTER INSERT ON group_participant_device BEGIN DELETE FROM backup_changes WHERE (table_name = 'group_participant_device') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'group_participant_device', NEW._id);  END;
CREATE TRIGGER group_participant_device_update_for_backup_changes_trigger AFTER UPDATE ON group_participant_device BEGIN DELETE FROM backup_changes WHERE (table_name = 'group_participant_device') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'group_participant_device', NEW._id);  END;
CREATE TRIGGER group_participant_user_delete_for_backup_changes_trigger AFTER DELETE ON group_participant_user BEGIN DELETE FROM backup_changes WHERE (table_name = 'group_participant_user') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'group_participant_user', OLD._id);  END;
CREATE TRIGGER group_participant_user_insert_for_backup_changes_trigger AFTER INSERT ON group_participant_user BEGIN DELETE FROM backup_changes WHERE (table_name = 'group_participant_user') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'group_participant_user', NEW._id);  END;
CREATE TRIGGER group_participant_user_update_for_backup_changes_trigger AFTER UPDATE ON group_participant_user BEGIN DELETE FROM backup_changes WHERE (table_name = 'group_participant_user') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'group_participant_user', NEW._id);  END;
CREATE TRIGGER group_past_participant_user_delete_for_backup_changes_trigger AFTER DELETE ON group_past_participant_user BEGIN DELETE FROM backup_changes WHERE (table_name = 'group_past_participant_user') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'group_past_participant_user', OLD._id);  END;
CREATE TRIGGER group_past_participant_user_insert_for_backup_changes_trigger AFTER INSERT ON group_past_participant_user BEGIN DELETE FROM backup_changes WHERE (table_name = 'group_past_participant_user') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'group_past_participant_user', NEW._id);  END;
CREATE TRIGGER group_past_participant_user_update_for_backup_changes_trigger AFTER UPDATE ON group_past_participant_user BEGIN DELETE FROM backup_changes WHERE (table_name = 'group_past_participant_user') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'group_past_participant_user', NEW._id);  END;
CREATE TRIGGER jid_delete_for_backup_changes_trigger AFTER DELETE ON jid BEGIN DELETE FROM backup_changes WHERE (table_name = 'jid') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'jid', OLD._id);  END;
CREATE TRIGGER jid_insert_for_backup_changes_trigger AFTER INSERT ON jid BEGIN DELETE FROM backup_changes WHERE (table_name = 'jid') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'jid', NEW._id);  END;
CREATE TRIGGER jid_update_for_backup_changes_trigger AFTER UPDATE ON jid BEGIN DELETE FROM backup_changes WHERE (table_name = 'jid') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'jid', NEW._id);  END;
CREATE TRIGGER joinable_call_log_delete_for_backup_changes_trigger AFTER DELETE ON joinable_call_log BEGIN DELETE FROM backup_changes WHERE (table_name = 'joinable_call_log') AND (table_row_id = OLD.call_log_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'joinable_call_log', OLD.call_log_row_id);  END;
CREATE TRIGGER joinable_call_log_insert_for_backup_changes_trigger AFTER INSERT ON joinable_call_log BEGIN DELETE FROM backup_changes WHERE (table_name = 'joinable_call_log') AND (table_row_id = NEW.call_log_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'joinable_call_log', NEW.call_log_row_id);  END;
CREATE TRIGGER joinable_call_log_update_for_backup_changes_trigger AFTER UPDATE ON joinable_call_log BEGIN DELETE FROM backup_changes WHERE (table_name = 'joinable_call_log') AND (table_row_id = NEW.call_log_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'joinable_call_log', NEW.call_log_row_id);  END;
CREATE TRIGGER keywords_delete_for_backup_changes_trigger AFTER DELETE ON keywords BEGIN DELETE FROM backup_changes WHERE (table_name = 'keywords') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'keywords', OLD._id);  END;
CREATE TRIGGER keywords_insert_for_backup_changes_trigger AFTER INSERT ON keywords BEGIN DELETE FROM backup_changes WHERE (table_name = 'keywords') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'keywords', NEW._id);  END;
CREATE TRIGGER keywords_update_for_backup_changes_trigger AFTER UPDATE ON keywords BEGIN DELETE FROM backup_changes WHERE (table_name = 'keywords') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'keywords', NEW._id);  END;
CREATE TRIGGER lid_chat_state_delete_for_backup_changes_trigger AFTER DELETE ON lid_chat_state BEGIN DELETE FROM backup_changes WHERE (table_name = 'lid_chat_state') AND (table_row_id = OLD.jid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'lid_chat_state', OLD.jid_row_id);  END;
CREATE TRIGGER lid_chat_state_insert_for_backup_changes_trigger AFTER INSERT ON lid_chat_state BEGIN DELETE FROM backup_changes WHERE (table_name = 'lid_chat_state') AND (table_row_id = NEW.jid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'lid_chat_state', NEW.jid_row_id);  END;
CREATE TRIGGER lid_chat_state_update_for_backup_changes_trigger AFTER UPDATE ON lid_chat_state BEGIN DELETE FROM backup_changes WHERE (table_name = 'lid_chat_state') AND (table_row_id = NEW.jid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'lid_chat_state', NEW.jid_row_id);  END;
CREATE TRIGGER lid_display_name_delete_for_backup_changes_trigger AFTER DELETE ON lid_display_name BEGIN DELETE FROM backup_changes WHERE (table_name = 'lid_display_name') AND (table_row_id = OLD.lid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'lid_display_name', OLD.lid_row_id);  END;
CREATE TRIGGER lid_display_name_insert_for_backup_changes_trigger AFTER INSERT ON lid_display_name BEGIN DELETE FROM backup_changes WHERE (table_name = 'lid_display_name') AND (table_row_id = NEW.lid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'lid_display_name', NEW.lid_row_id);  END;
CREATE TRIGGER lid_display_name_update_for_backup_changes_trigger AFTER UPDATE ON lid_display_name BEGIN DELETE FROM backup_changes WHERE (table_name = 'lid_display_name') AND (table_row_id = NEW.lid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'lid_display_name', NEW.lid_row_id);  END;
CREATE TRIGGER media_refs_delete_for_backup_changes_trigger AFTER DELETE ON media_refs BEGIN DELETE FROM backup_changes WHERE (table_name = 'media_refs') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'media_refs', OLD._id);  END;
CREATE TRIGGER media_refs_insert_for_backup_changes_trigger AFTER INSERT ON media_refs BEGIN DELETE FROM backup_changes WHERE (table_name = 'media_refs') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'media_refs', NEW._id);  END;
CREATE TRIGGER media_refs_update_for_backup_changes_trigger AFTER UPDATE ON media_refs BEGIN DELETE FROM backup_changes WHERE (table_name = 'media_refs') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'media_refs', NEW._id);  END;
CREATE TRIGGER message_add_on_delete_for_backup_changes_trigger AFTER DELETE ON message_add_on BEGIN DELETE FROM backup_changes WHERE (table_name = 'message') AND (table_row_id = OLD.parent_message_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'message', OLD.parent_message_row_id);  END;
CREATE TRIGGER message_add_on_insert_for_backup_changes_trigger AFTER INSERT ON message_add_on BEGIN DELETE FROM backup_changes WHERE (table_name = 'message') AND (table_row_id = NEW.parent_message_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'message', NEW.parent_message_row_id);  END;
CREATE TRIGGER message_add_on_receipt_device_delete_for_backup_changes_trigger AFTER DELETE ON message_add_on_receipt_device BEGIN DELETE FROM backup_changes WHERE (table_name = 'message_add_on_receipt_device') AND (table_row_id = OLD.receipt_device_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'message_add_on_receipt_device', OLD.receipt_device_id);  END;
CREATE TRIGGER message_add_on_receipt_device_insert_for_backup_changes_trigger AFTER INSERT ON message_add_on_receipt_device BEGIN DELETE FROM backup_changes WHERE (table_name = 'message_add_on_receipt_device') AND (table_row_id = NEW.receipt_device_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'message_add_on_receipt_device', NEW.receipt_device_id);  END;
CREATE TRIGGER message_add_on_receipt_device_update_for_backup_changes_trigger AFTER UPDATE ON message_add_on_receipt_device BEGIN DELETE FROM backup_changes WHERE (table_name = 'message_add_on_receipt_device') AND (table_row_id = NEW.receipt_device_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'message_add_on_receipt_device', NEW.receipt_device_id);  END;
CREATE TRIGGER message_add_on_update_for_backup_changes_trigger AFTER UPDATE ON message_add_on BEGIN DELETE FROM backup_changes WHERE (table_name = 'message') AND (table_row_id = NEW.parent_message_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'message', NEW.parent_message_row_id);  END;
CREATE TRIGGER message_bd_for_bot_message_prompts_trigger BEFORE DELETE ON message BEGIN DELETE FROM bot_message_prompts WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_fixed_content_placeholder_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_fixed_content_placeholder WHERE message_row_id=old._id; END;
CREATE TRIGGER message_bd_for_message_parent_association_trigger BEFORE DELETE ON message BEGIN DELETE FROM message_parent_association WHERE message_row_id=old._id; END;
CREATE TRIGGER message_delete_for_backup_changes_trigger AFTER DELETE ON message BEGIN DELETE FROM backup_changes WHERE (table_name = 'message') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'message', OLD._id);  END;
CREATE TRIGGER message_insert_for_backup_changes_trigger AFTER INSERT ON message BEGIN DELETE FROM backup_changes WHERE (table_name = 'message') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'message', NEW._id);  END;
CREATE TRIGGER message_system_bd_for_message_system_event_updates_trigger BEFORE DELETE ON message_system BEGIN DELETE FROM message_system_event_updates WHERE message_row_id=old.message_row_id; END;
CREATE TRIGGER message_update_for_backup_changes_trigger AFTER UPDATE ON message BEGIN DELETE FROM backup_changes WHERE (table_name = 'message') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'message', NEW._id);  END;
CREATE TRIGGER parent_group_participants_delete_for_backup_changes_trigger AFTER DELETE ON parent_group_participants BEGIN DELETE FROM backup_changes WHERE (table_name = 'parent_group_participants') AND (table_row_id = OLD.rowid) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'parent_group_participants', OLD.rowid);  END;
CREATE TRIGGER parent_group_participants_insert_for_backup_changes_trigger AFTER INSERT ON parent_group_participants BEGIN DELETE FROM backup_changes WHERE (table_name = 'parent_group_participants') AND (table_row_id = NEW.rowid) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'parent_group_participants', NEW.rowid);  END;
CREATE TRIGGER parent_group_participants_update_for_backup_changes_trigger AFTER UPDATE ON parent_group_participants BEGIN DELETE FROM backup_changes WHERE (table_name = 'parent_group_participants') AND (table_row_id = NEW.rowid) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'parent_group_participants', NEW.rowid);  END;
CREATE TRIGGER pay_transaction_delete_for_backup_changes_trigger AFTER DELETE ON pay_transaction BEGIN DELETE FROM backup_changes WHERE (table_name = 'pay_transaction') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'pay_transaction', OLD._id);  END;
CREATE TRIGGER pay_transaction_insert_for_backup_changes_trigger AFTER INSERT ON pay_transaction BEGIN DELETE FROM backup_changes WHERE (table_name = 'pay_transaction') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'pay_transaction', NEW._id);  END;
CREATE TRIGGER pay_transaction_update_for_backup_changes_trigger AFTER UPDATE ON pay_transaction BEGIN DELETE FROM backup_changes WHERE (table_name = 'pay_transaction') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'pay_transaction', NEW._id);  END;
CREATE TRIGGER payment_background_delete_for_backup_changes_trigger AFTER DELETE ON payment_background BEGIN DELETE FROM backup_changes WHERE (table_name = 'payment_background') AND (table_row_id = OLD.rowid) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'payment_background', OLD.rowid);  END;
CREATE TRIGGER payment_background_insert_for_backup_changes_trigger AFTER INSERT ON payment_background BEGIN DELETE FROM backup_changes WHERE (table_name = 'payment_background') AND (table_row_id = NEW.rowid) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'payment_background', NEW.rowid);  END;
CREATE TRIGGER payment_background_order_delete_for_backup_changes_trigger AFTER DELETE ON payment_background_order BEGIN DELETE FROM backup_changes WHERE (table_name = 'payment_background_order') AND (table_row_id = OLD.rowid) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'payment_background_order', OLD.rowid);  END;
CREATE TRIGGER payment_background_order_insert_for_backup_changes_trigger AFTER INSERT ON payment_background_order BEGIN DELETE FROM backup_changes WHERE (table_name = 'payment_background_order') AND (table_row_id = NEW.rowid) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'payment_background_order', NEW.rowid);  END;
CREATE TRIGGER payment_background_order_update_for_backup_changes_trigger AFTER UPDATE ON payment_background_order BEGIN DELETE FROM backup_changes WHERE (table_name = 'payment_background_order') AND (table_row_id = NEW.rowid) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'payment_background_order', NEW.rowid);  END;
CREATE TRIGGER payment_background_update_for_backup_changes_trigger AFTER UPDATE ON payment_background BEGIN DELETE FROM backup_changes WHERE (table_name = 'payment_background') AND (table_row_id = NEW.rowid) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'payment_background', NEW.rowid);  END;
CREATE TRIGGER played_self_receipt_delete_for_backup_changes_trigger AFTER DELETE ON played_self_receipt BEGIN DELETE FROM backup_changes WHERE (table_name = 'played_self_receipt') AND (table_row_id = OLD.message_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'played_self_receipt', OLD.message_row_id);  END;
CREATE TRIGGER played_self_receipt_insert_for_backup_changes_trigger AFTER INSERT ON played_self_receipt BEGIN DELETE FROM backup_changes WHERE (table_name = 'played_self_receipt') AND (table_row_id = NEW.message_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'played_self_receipt', NEW.message_row_id);  END;
CREATE TRIGGER played_self_receipt_update_for_backup_changes_trigger AFTER UPDATE ON played_self_receipt BEGIN DELETE FROM backup_changes WHERE (table_name = 'played_self_receipt') AND (table_row_id = NEW.message_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'played_self_receipt', NEW.message_row_id);  END;
CREATE TRIGGER primary_device_version_delete_for_backup_changes_trigger AFTER DELETE ON primary_device_version BEGIN DELETE FROM backup_changes WHERE (table_name = 'primary_device_version') AND (table_row_id = OLD.user_jid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'primary_device_version', OLD.user_jid_row_id);  END;
CREATE TRIGGER primary_device_version_insert_for_backup_changes_trigger AFTER INSERT ON primary_device_version BEGIN DELETE FROM backup_changes WHERE (table_name = 'primary_device_version') AND (table_row_id = NEW.user_jid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'primary_device_version', NEW.user_jid_row_id);  END;
CREATE TRIGGER primary_device_version_update_for_backup_changes_trigger AFTER UPDATE ON primary_device_version BEGIN DELETE FROM backup_changes WHERE (table_name = 'primary_device_version') AND (table_row_id = NEW.user_jid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'primary_device_version', NEW.user_jid_row_id);  END;
CREATE TRIGGER props_delete_for_backup_changes_trigger AFTER DELETE ON props BEGIN DELETE FROM backup_changes WHERE (table_name = 'props') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'props', OLD._id);  END;
CREATE TRIGGER props_insert_for_backup_changes_trigger AFTER INSERT ON props BEGIN DELETE FROM backup_changes WHERE (table_name = 'props') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'props', NEW._id);  END;
CREATE TRIGGER props_update_for_backup_changes_trigger AFTER UPDATE ON props BEGIN DELETE FROM backup_changes WHERE (table_name = 'props') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'props', NEW._id);  END;
CREATE TRIGGER quick_replies_delete_for_backup_changes_trigger AFTER DELETE ON quick_replies BEGIN DELETE FROM backup_changes WHERE (table_name = 'quick_replies') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'quick_replies', OLD._id);  END;
CREATE TRIGGER quick_replies_insert_for_backup_changes_trigger AFTER INSERT ON quick_replies BEGIN DELETE FROM backup_changes WHERE (table_name = 'quick_replies') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'quick_replies', NEW._id);  END;
CREATE TRIGGER quick_replies_update_for_backup_changes_trigger AFTER UPDATE ON quick_replies BEGIN DELETE FROM backup_changes WHERE (table_name = 'quick_replies') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'quick_replies', NEW._id);  END;
CREATE TRIGGER quick_reply_attachments_delete_for_backup_changes_trigger AFTER DELETE ON quick_reply_attachments BEGIN DELETE FROM backup_changes WHERE (table_name = 'quick_reply_attachments') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'quick_reply_attachments', OLD._id);  END;
CREATE TRIGGER quick_reply_attachments_insert_for_backup_changes_trigger AFTER INSERT ON quick_reply_attachments BEGIN DELETE FROM backup_changes WHERE (table_name = 'quick_reply_attachments') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'quick_reply_attachments', NEW._id);  END;
CREATE TRIGGER quick_reply_attachments_update_for_backup_changes_trigger AFTER UPDATE ON quick_reply_attachments BEGIN DELETE FROM backup_changes WHERE (table_name = 'quick_reply_attachments') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'quick_reply_attachments', NEW._id);  END;
CREATE TRIGGER quick_reply_keywords_delete_for_backup_changes_trigger AFTER DELETE ON quick_reply_keywords BEGIN DELETE FROM backup_changes WHERE (table_name = 'quick_reply_keywords') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'quick_reply_keywords', OLD._id);  END;
CREATE TRIGGER quick_reply_keywords_insert_for_backup_changes_trigger AFTER INSERT ON quick_reply_keywords BEGIN DELETE FROM backup_changes WHERE (table_name = 'quick_reply_keywords') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'quick_reply_keywords', NEW._id);  END;
CREATE TRIGGER quick_reply_keywords_update_for_backup_changes_trigger AFTER UPDATE ON quick_reply_keywords BEGIN DELETE FROM backup_changes WHERE (table_name = 'quick_reply_keywords') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'quick_reply_keywords', NEW._id);  END;
CREATE TRIGGER quick_reply_usage_delete_for_backup_changes_trigger AFTER DELETE ON quick_reply_usage BEGIN DELETE FROM backup_changes WHERE (table_name = 'quick_reply_usage') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'quick_reply_usage', OLD._id);  END;
CREATE TRIGGER quick_reply_usage_insert_for_backup_changes_trigger AFTER INSERT ON quick_reply_usage BEGIN DELETE FROM backup_changes WHERE (table_name = 'quick_reply_usage') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'quick_reply_usage', NEW._id);  END;
CREATE TRIGGER quick_reply_usage_update_for_backup_changes_trigger AFTER UPDATE ON quick_reply_usage BEGIN DELETE FROM backup_changes WHERE (table_name = 'quick_reply_usage') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'quick_reply_usage', NEW._id);  END;
CREATE TRIGGER receipt_device_delete_for_backup_changes_trigger AFTER DELETE ON receipt_device BEGIN DELETE FROM backup_changes WHERE (table_name = 'receipt_device') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'receipt_device', OLD._id);  END;
CREATE TRIGGER receipt_device_insert_for_backup_changes_trigger AFTER INSERT ON receipt_device BEGIN DELETE FROM backup_changes WHERE (table_name = 'receipt_device') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'receipt_device', NEW._id);  END;
CREATE TRIGGER receipt_device_update_for_backup_changes_trigger AFTER UPDATE ON receipt_device BEGIN DELETE FROM backup_changes WHERE (table_name = 'receipt_device') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'receipt_device', NEW._id);  END;
CREATE TRIGGER receipt_orphaned_delete_for_backup_changes_trigger AFTER DELETE ON receipt_orphaned BEGIN DELETE FROM backup_changes WHERE (table_name = 'receipt_orphaned') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'receipt_orphaned', OLD._id);  END;
CREATE TRIGGER receipt_orphaned_insert_for_backup_changes_trigger AFTER INSERT ON receipt_orphaned BEGIN DELETE FROM backup_changes WHERE (table_name = 'receipt_orphaned') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'receipt_orphaned', NEW._id);  END;
CREATE TRIGGER receipt_orphaned_update_for_backup_changes_trigger AFTER UPDATE ON receipt_orphaned BEGIN DELETE FROM backup_changes WHERE (table_name = 'receipt_orphaned') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'receipt_orphaned', NEW._id);  END;
CREATE TRIGGER receipt_user_delete_for_backup_changes_trigger AFTER DELETE ON receipt_user BEGIN DELETE FROM backup_changes WHERE (table_name = 'receipt_user') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'receipt_user', OLD._id);  END;
CREATE TRIGGER receipt_user_insert_for_backup_changes_trigger AFTER INSERT ON receipt_user BEGIN DELETE FROM backup_changes WHERE (table_name = 'receipt_user') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'receipt_user', NEW._id);  END;
CREATE TRIGGER receipt_user_update_for_backup_changes_trigger AFTER UPDATE ON receipt_user BEGIN DELETE FROM backup_changes WHERE (table_name = 'receipt_user') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'receipt_user', NEW._id);  END;
CREATE TRIGGER user_device_delete_for_backup_changes_trigger AFTER DELETE ON user_device BEGIN DELETE FROM backup_changes WHERE (table_name = 'user_device') AND (table_row_id = OLD._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'user_device', OLD._id);  END;
CREATE TRIGGER user_device_info_delete_for_backup_changes_trigger AFTER DELETE ON user_device_info BEGIN DELETE FROM backup_changes WHERE (table_name = 'user_device_info') AND (table_row_id = OLD.user_jid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('DELETE', 'user_device_info', OLD.user_jid_row_id);  END;
CREATE TRIGGER user_device_info_insert_for_backup_changes_trigger AFTER INSERT ON user_device_info BEGIN DELETE FROM backup_changes WHERE (table_name = 'user_device_info') AND (table_row_id = NEW.user_jid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'user_device_info', NEW.user_jid_row_id);  END;
CREATE TRIGGER user_device_info_update_for_backup_changes_trigger AFTER UPDATE ON user_device_info BEGIN DELETE FROM backup_changes WHERE (table_name = 'user_device_info') AND (table_row_id = NEW.user_jid_row_id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'user_device_info', NEW.user_jid_row_id);  END;
CREATE TRIGGER user_device_insert_for_backup_changes_trigger AFTER INSERT ON user_device BEGIN DELETE FROM backup_changes WHERE (table_name = 'user_device') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('INSERT', 'user_device', NEW._id);  END;
CREATE TRIGGER user_device_update_for_backup_changes_trigger AFTER UPDATE ON user_device BEGIN DELETE FROM backup_changes WHERE (table_name = 'user_device') AND (table_row_id = NEW._id) AND ((operation = 'INSERT') OR (operation = 'UPDATE')); INSERT INTO backup_changes(operation, table_name, table_row_id ) VALUES('UPDATE', 'user_device', NEW._id);  END;
CREATE TRIGGER suggest_as_you_type_delete_oldest_trigger BEFORE INSERT ON suggest_as_you_type FOR EACH ROW WHEN (SELECT COUNT(*) FROM suggest_as_you_type ) > 2000 BEGIN DELETE FROM suggest_as_you_type WHERE message_row_id = (SELECT MIN(message_row_id) FROM suggest_as_you_type); END;
CREATE TRIGGER suggested_replies_delete_oldest_trigger BEFORE INSERT ON suggested_replies FOR EACH ROW WHEN (SELECT COUNT(*) FROM suggested_replies ) > 2000 BEGIN DELETE FROM suggested_replies WHERE message_row_id = (SELECT MIN(message_row_id) FROM suggested_replies); END;
CREATE VIEW message_view AS SELECT message._id AS _id, message.sort_id AS sort_id, message.chat_row_id AS chat_row_id, from_me, key_id, sender_jid_row_id, NULL AS sender_jid_raw_string, status, broadcast, recipient_count, participant_hash, origination_flags, origin, timestamp, received_timestamp, receipt_server_timestamp, message_type, text_data, starred, lookup_tables, message_add_on_flags, view_mode, NULL AS data, NULL AS media_url, NULL AS media_mime_type, NULL AS media_size, NULL AS media_name, NULL AS media_caption, NULL AS media_hash, NULL AS media_duration, NULL AS latitude, NULL AS longitude, NULL AS thumb_image, NULL AS raw_data, NULL AS quoted_row_id, NULL AS mentioned_jids, NULL AS multicast_id, NULL AS edit_version, NULL AS media_enc_hash, NULL AS payment_transaction_id, NULL AS preview_type, NULL AS receipt_device_timestamp, NULL AS read_device_timestamp, NULL AS played_device_timestamp, NULL AS future_message_type, 2 AS table_version FROM message;
CREATE VIEW available_message_view AS  SELECT message._id AS _id, message.sort_id AS sort_id, message.chat_row_id AS chat_row_id, from_me, key_id, sender_jid_row_id, NULL AS sender_jid_raw_string, status, broadcast, recipient_count, participant_hash, origination_flags, origin, timestamp, received_timestamp, receipt_server_timestamp, message_type, text_data, starred, lookup_tables, message_add_on_flags, view_mode, NULL AS data, NULL AS media_url, NULL AS media_mime_type, NULL AS media_size, NULL AS media_name, NULL AS media_caption, NULL AS media_hash, NULL AS media_duration, NULL AS latitude, NULL AS longitude, NULL AS thumb_image, NULL AS raw_data, NULL AS quoted_row_id, NULL AS mentioned_jids, NULL AS multicast_id, NULL AS edit_version, NULL AS media_enc_hash, NULL AS payment_transaction_id, NULL AS preview_type, NULL AS receipt_device_timestamp, NULL AS read_device_timestamp, NULL AS played_device_timestamp, NULL AS future_message_type, 2 AS table_version, expire_timestamp, keep_in_chat FROM message LEFT JOIN deleted_chat_job AS job ON job.chat_row_id = message.chat_row_id LEFT JOIN message_ephemeral AS message_ephemeral ON message._id = message_ephemeral.message_row_id WHERE  IFNULL(NOT((IFNULL(message.starred, 0) = 0 AND message.sort_id <= IFNULL(job.deleted_message_row_id, -9223372036854775808)) OR (IFNULL(message.starred, 0) = 1 AND message.sort_id <= IFNULL(job.deleted_starred_message_row_id, -9223372036854775808)) OR ( (job.deleted_message_categories IS NOT NULL) AND (job.deleted_message_categories LIKE '%"' || message.message_type || '"%') AND ((IFNULL(message.starred, 0) = 0 AND message.sort_id <= IFNULL(job.deleted_categories_message_row_id, -9223372036854775808)) OR (IFNULL(message.starred, 0) = 1 AND message.sort_id <= IFNULL(job.deleted_categories_starred_message_row_id, -9223372036854775808)))) OR ((job.singular_message_delete_rows_id IS NOT NULL) AND (job.singular_message_delete_rows_id LIKE '%"' || message._id || '"%'))), 0);
CREATE VIEW deleted_messages_view AS   SELECT message._id AS _id, message.sort_id AS sort_id, message.chat_row_id AS chat_row_id, from_me, key_id, sender_jid_row_id, NULL AS sender_jid_raw_string, status, broadcast, recipient_count, participant_hash, origination_flags, origin, timestamp, received_timestamp, receipt_server_timestamp, message_type, text_data, starred, lookup_tables, message_add_on_flags, view_mode, NULL AS data, NULL AS media_url, NULL AS media_mime_type, NULL AS media_size, NULL AS media_name, NULL AS media_caption, NULL AS media_hash, NULL AS media_duration, NULL AS latitude, NULL AS longitude, NULL AS thumb_image, NULL AS raw_data, NULL AS quoted_row_id, NULL AS mentioned_jids, NULL AS multicast_id, NULL AS edit_version, NULL AS media_enc_hash, NULL AS payment_transaction_id, NULL AS preview_type, NULL AS receipt_device_timestamp, NULL AS read_device_timestamp, NULL AS played_device_timestamp, NULL AS future_message_type, 2 AS table_version, ((((job.singular_message_delete_rows_id LIKE '%"' || message._id || '"%') AND (job.delete_files_singular_delete== 1)) OR ((job.deleted_messages_remove_files == 1) AND ((IFNULL(message.starred, 0) = 0 AND message.sort_id <= IFNULL(job.deleted_message_row_id, -9223372036854775808)) OR (IFNULL(message.starred, 0) = 1 AND message.sort_id <= IFNULL(job.deleted_starred_message_row_id, -9223372036854775808)))) OR ((job.deleted_categories_remove_files == 1) AND ( (job.deleted_message_categories IS NOT NULL) AND (job.deleted_message_categories LIKE '%"' || message.message_type || '"%') AND ((IFNULL(message.starred, 0) = 0 AND message.sort_id <= IFNULL(job.deleted_categories_message_row_id, -9223372036854775808)) OR (IFNULL(message.starred, 0) = 1 AND message.sort_id <= IFNULL(job.deleted_categories_starred_message_row_id, -9223372036854775808))))))) as remove_files FROM  deleted_chat_job AS job JOIN message AS message  ON job.chat_row_id = message.chat_row_id   WHERE  IFNULL((IFNULL(message.starred, 0) = 0 AND message.sort_id <= IFNULL(job.deleted_message_row_id, -9223372036854775808)) OR (IFNULL(message.starred, 0) = 1 AND message.sort_id <= IFNULL(job.deleted_starred_message_row_id, -9223372036854775808)) OR ( (job.deleted_message_categories IS NOT NULL) AND (job.deleted_message_categories LIKE '%"' || message.message_type || '"%') AND ((IFNULL(message.starred, 0) = 0 AND message.sort_id <= IFNULL(job.deleted_categories_message_row_id, -9223372036854775808)) OR (IFNULL(message.starred, 0) = 1 AND message.sort_id <= IFNULL(job.deleted_categories_starred_message_row_id, -9223372036854775808)))) OR ((job.singular_message_delete_rows_id IS NOT NULL) AND (job.singular_message_delete_rows_id LIKE '%"' || message._id || '"%')), 0) ORDER BY message._id;
CREATE VIEW deleted_messages_ids_view AS  SELECT message._id, message.sort_id, message.chat_row_id, message.message_type FROM deleted_chat_job AS job  JOIN message AS message  ON job.chat_row_id = message.chat_row_id WHERE  IFNULL((IFNULL(message.starred, 0) = 0 AND message.sort_id <= IFNULL(job.deleted_message_row_id, -9223372036854775808)) OR (IFNULL(message.starred, 0) = 1 AND message.sort_id <= IFNULL(job.deleted_starred_message_row_id, -9223372036854775808)) OR ( (job.deleted_message_categories IS NOT NULL) AND (job.deleted_message_categories LIKE '%"' || message.message_type || '"%') AND ((IFNULL(message.starred, 0) = 0 AND message.sort_id <= IFNULL(job.deleted_categories_message_row_id, -9223372036854775808)) OR (IFNULL(message.starred, 0) = 1 AND message.sort_id <= IFNULL(job.deleted_categories_starred_message_row_id, -9223372036854775808)))) OR ((job.singular_message_delete_rows_id IS NOT NULL) AND (job.singular_message_delete_rows_id LIKE '%"' || message._id || '"%')), 0);
CREATE VIEW chat_view AS SELECT chat._id AS _id, jid.raw_string AS raw_string_jid, hidden AS hidden, subject AS subject, created_timestamp AS created_timestamp, display_message_row_id AS display_message_row_id, last_message_row_id AS last_message_row_id, last_read_message_row_id AS last_read_message_row_id, last_read_receipt_sent_message_row_id AS last_read_receipt_sent_message_row_id, last_important_message_row_id AS last_important_message_row_id, archived AS archived, sort_timestamp AS sort_timestamp, mod_tag AS mod_tag, gen AS gen, spam_detection AS spam_detection, unseen_earliest_message_received_time AS unseen_earliest_message_received_time, unseen_message_count AS unseen_message_count, unseen_missed_calls_count AS unseen_missed_calls_count, unseen_row_count AS unseen_row_count, unseen_message_reaction_count AS unseen_message_reaction_count, unseen_comment_message_count AS unseen_comment_message_count, last_message_reaction_row_id AS last_message_reaction_row_id, last_seen_message_reaction_row_id AS last_seen_message_reaction_row_id, plaintext_disabled AS plaintext_disabled, vcard_ui_dismissed AS vcard_ui_dismissed, change_number_notified_message_row_id AS change_number_notified_message_row_id, show_group_description AS show_group_description, ephemeral_expiration AS ephemeral_expiration, last_read_ephemeral_message_row_id AS last_read_ephemeral_message_row_id, ephemeral_setting_timestamp AS ephemeral_setting_timestamp, ephemeral_displayed_exemptions AS ephemeral_displayed_exemptions, ephemeral_disappearing_messages_initiator AS ephemeral_disappearing_messages_initiator, unseen_important_message_count AS unseen_important_message_count, group_type AS group_type, growth_lock_level AS growth_lock_level, growth_lock_expiration_ts AS growth_lock_expiration_ts, last_read_message_sort_id AS last_read_message_sort_id, display_message_sort_id AS display_message_sort_id, last_message_sort_id AS last_message_sort_id, last_read_receipt_sent_message_sort_id AS last_read_receipt_sent_message_sort_id, has_new_community_admin_dialog_been_acknowledged AS has_new_community_admin_dialog_been_acknowledged, history_sync_progress AS history_sync_progress, chat_lock AS chat_lock, chat_origin AS chat_origin FROM chat chat LEFT JOIN jid jid ON chat.jid_row_id = jid._id;
COMMIT;
